@@ -19,9 +19,9 @@ from oslo_log import log as logging
 import oslo_messaging as messaging
 
 from octavia.common import constants
-from octavia.common import rpc
 from octavia.db import api as db_apis
 from octavia.db import repositories
+from octavia_lib.api.drivers import data_models as driver_dm
 from octavia_lib.api.drivers import exceptions
 from octavia_lib.api.drivers import provider_base as driver_base
 
@@ -36,16 +36,30 @@ LOG = logging.getLogger(__name__)
 class A10ProviderDriver(driver_base.ProviderDriver):
     def __init__(self):
         super(A10ProviderDriver, self).__init__()
-        self.target = messaging.Target(
-            namespace=constants.RPC_NAMESPACE_CONTROLLER_AGENT,
-            topic='a10_octavia', version='1.0', fanout=False
-        )
-        self.client = rpc.get_client(self.target)
+        self._args = {}
+        self.transport = messaging.get_rpc_transport(cfg.CONF)
+        self._args['fanout'] = False
+        self._args['namespace'] = constants.RPC_NAMESPACE_CONTROLLER_AGENT
+        self._args['topic'] = "a10_octavia"
+        self._args['version'] = '1.0'
+        self.target = messaging.Target(**self._args)
+        self.client = messaging.RPCClient(self.transport, target=self.target)
         self.repositories = repositories.Repositories()
 
     # Load Balancer
+    def create_vip_port(self, loadbalancer_id, project_id, vip_dictionary):
+        # raise NotImplementedError to let octavia create port for us.
+        raise exceptions.NotImplementedError(
+            user_fault_string='The a10 provider does not implement custom create_vip_port()',
+            operator_fault_string='The a10 provider does not implement custom create_vip_port()'
+        )
+
     def loadbalancer_create(self, loadbalancer):
         LOG.info('A10 provider load balancer loadbalancer: %s.', loadbalancer.__dict__)
+        if loadbalancer.flavor == driver_dm.Unset:
+            loadbalancer.flavor = None
+        if loadbalancer.availability_zone == driver_dm.Unset:
+            loadbalancer.availability_zone = None
         payload = {constants.LOAD_BALANCER_ID: loadbalancer.loadbalancer_id,
                    constants.FLAVOR: loadbalancer.flavor}
         self.client.cast({}, 'create_load_balancer', **payload)
@@ -150,14 +164,12 @@ class A10ProviderDriver(driver_base.ProviderDriver):
                    constants.MEMBER_UPDATES: member_dict}
         self.client.cast({}, 'update_member', **payload)
 
-    def member_batch_update(self, members):
-        pool_id = members[0].pool_id
-        # The DB should not have updated yet, so we can still use the pool
-        db_pool = self.repositories.pool.get(db_apis.get_session(), id=pool_id)
+    def member_batch_update(self, pool_id, members):
+        pool = self.repositories.pool.get(db_apis.get_session(), id=pool_id)
+
+        old_members = pool.members
 
-        old_members = db_pool.members
         old_member_ids = [m.id for m in old_members]
-
         # The driver will always pass objects with IDs.
         new_member_ids = [m.member_id for m in members]
 
@@ -276,6 +288,13 @@ class A10ProviderDriver(driver_base.ProviderDriver):
                 operator_fault_string='Failed to get the supported flavor '
                                       'metadata due to: {}'.format(str(e)))
 
+    def _validate_flavor_name_expressions(self, obj_flavor):
+        if 'name-expressions' in obj_flavor:
+            for reg_flavor in obj_flavor['name-expressions']:
+                if 'regex' not in reg_flavor or 'json' not in reg_flavor:
+                    raise Exception(
+                        'key \'regex\' and \'json\' is mandatory for \'name-expressions\'')
+
     def validate_flavor(self, flavor_dict):
         try:
             validate(flavor_dict, flavor_schema.SUPPORTED_FLAVOR_SCHEMA)
@@ -287,6 +306,7 @@ class A10ProviderDriver(driver_base.ProviderDriver):
                     raise Exception('axapi key \'name\' is not allowed')
                 if 'ip-address' in flavor:
                     raise Exception('axapi key \'ip-address\' is not supported yet')
+                self._validate_flavor_name_expressions(flavor)
             if 'virtual-port' in flavor_dict:
                 flavor = flavor_dict['virtual-port']
                 if 'name' in flavor:
@@ -295,18 +315,22 @@ class A10ProviderDriver(driver_base.ProviderDriver):
                     raise Exception('axapi key \'port-number\' is not allowed')
                 if 'protocol' in flavor:
                     raise Exception('axapi key \'protocol\' is not allowed')
+                self._validate_flavor_name_expressions(flavor)
             if 'service-group' in flavor_dict:
                 flavor = flavor_dict['service-group']
                 if 'name' in flavor:
                     raise Exception('axapi key \'name\' is not allowed')
+                self._validate_flavor_name_expressions(flavor)
             if 'server' in flavor_dict:
                 flavor = flavor_dict['server']
                 if 'name' in flavor:
                     raise Exception('axapi key \'name\' is not allowed')
+                self._validate_flavor_name_expressions(flavor)
             if 'health-monitor' in flavor_dict:
                 flavor = flavor_dict['health-monitor']
                 if 'name' in flavor:
                     raise Exception('axapi key \'name\' is not allowed')
+                self._validate_flavor_name_expressions(flavor)
 
             # validate nat-pool and nat-pool-list keys
             if 'nat-pool' in flavor_dict:
@@ -348,3 +372,36 @@ class A10ProviderDriver(driver_base.ProviderDriver):
                                   'due to: {}'.format(str(e)),
                 operator_fault_string='Failed to validate the flavor metadata '
                                       'due to: {}'.format(str(e)))
+
+    # Availability Zone
+    def get_supported_availability_zone_metadata(self):
+        """Returns the valid availability zone metadata keys and descriptions.
+
+        This extracts the valid availability zone metadata keys and
+        descriptions from the JSON validation schema and returns it as a
+        dictionary.
+
+        :return: Dictionary of availability zone metadata keys and descriptions
+        :raises DriverError: An unexpected error occurred.
+        """
+        # return empty dictionary for a10-octavia support nothing.
+        props = {}
+        return props
+
+    def validate_availability_zone(self, availability_zone_dict):
+        """Validates availability zone profile data.
+
+        This will validate an availability zone profile dataset against the
+        availability zone settings the amphora driver supports.
+
+        :param availability_zone_dict: The availability zone dict to validate.
+        :type availability_zone_dict: dict
+        :return: None
+        :raises DriverError: An unexpected error occurred.
+        :raises UnsupportedOptionError: If the driver does not support
+          one of the availability zone settings.
+        """
+        raise exceptions.NotImplementedError(
+            user_fault_string='The a10 provider does not support Availability zone feature',
+            operator_fault_string='The a10 provider does not support Availability zone feature'
+        )
