@@ -36,6 +36,10 @@ POOLS = 'pools'
 PARTITION_PROJECT_LIST = 'partition_project_list'
 IFNUM_BACKUP = 'ifnum_backup'
 IFNUM_MASTER = 'ifnum_master'
+LISTENER_STATS = 'listener_stats'
+
+# Octavia taskflow flow and task names (missing name in victoria octavia)
+RELOADLOAD_BALANCER = 'octavia-reloadload-balancer'
 
 VTHUNDER = 'vthunder'
 STATUS = 'status'
@@ -53,6 +57,8 @@ WRITE_MEM_PRIVATE = 'write_mem_private'
 
 FAILED = 'FAILED'
 USED_SPARE = 'USED_SPARE'
+SPARE_VTHUNDER = 'spare_vthunder'
+FAILOVER_VTHUNDER = 'failover_vthunder'
 OCTAVIA_HEALTH_MANAGER_CONTROLLER = 'octavia_health_manager_controller'
 OCTAVIA_HEALTH_MONITOR = 'octavia_health_monitor'
 VTHUNDER_CONFIG = 'vthunder_config'
@@ -83,6 +89,7 @@ MEMBER_COUNT = 'member_count'
 DELETE_VRID = 'delete_vrid'
 LB_COUNT_THUNDER = 'lb_count_thunder'
 MEMBER_COUNT_THUNDER = 'member_count_thunder'
+LB_COUNT_THUNDER_PARTITION = 'lb_count_thunder_partition'
 
 ID = 'id'
 SECURITY_GROUPS = 'security_groups'
@@ -100,6 +107,17 @@ SUPPORTED_NETWORK_TYPE = [FLAT, VLAN]
 SSL_TEMPLATE = "ssl_template"
 
 COMPUTE_BUSY = "compute_busy"
+VTHUNDER_LIST = "vthunder_list"
+NETWORK_LIST = "network_list"
+ADDED_NETWORK = "added_network"
+
+COMPUTE_PAUSED = "PAUSED"
+L2DSR_FLAVOR = "l2dsr_flavor"
+MASTER_AMPHORA_STATUS = "master_amphora_status"
+BACKUP_AMPHORA_STATUS = "backup_amphora_status"
+
+# ACOS versions
+ACOS_5_2_1_P2 = "5.2.1-P2"
 
 # ============================
 # Taskflow flow and task names
@@ -120,7 +138,10 @@ MARK_VTHUNDER_BACKUP_ACTIVE_IN_DB = 'mark-vthunder-backup-active-in-db'
 MARK_VTHUNDER_MASTER_DELETED_IN_DB = 'mark-vthunder-master-deleted-in-db'
 MARK_VTHUNDER_BACKUP_DELETED_IN_DB = 'mark-vthunder-backup-deleted-in-db'
 GET_BACKUP_VTHUNDER_BY_LB = 'get-backup-vthunder-by-lb'
-CREATE_HEALTH_MONITOR_ON_VTHUNDER_MASTER = 'create-health-monitor-on-vthunder-master'
+GET_VTHUNDER_FROM_LB = 'get-vthunder-from-lb'
+CREATE_HEALTH_MONITOR_ON_VTHUNDER = 'create-health-monitor-on-vthunder'
+CREATE_HEALTH_MONITOR_ON_SPARE = 'create-health-monitor-on-spare'
+MARK_AMPHORA_READY_INDB = 'mark-amphora-ready-indb'
 HANDLE_SESS_PERS = 'handle-session-persistence-delta-subflow'
 GET_LOADBALANCER_FROM_DB = 'Get-Loadbalancer-from-db'
 GET_BACKUP_LOADBALANCER_FROM_DB = 'get-backup-loadbalancer-from-db'
@@ -132,12 +153,14 @@ WAIT_FOR_MASTER_SYNC = 'wait-for-master-sync'
 WAIT_FOR_BACKUP_SYNC = 'wait-for-backup-sync'
 CONFIGURE_AVCS_SYNC_FOR_MASTER = 'configure-avcs-sync-for-master'
 CONFIGURE_AVCS_SYNC_FOR_BACKUP = 'configure-avcs-sync-for-backup'
+CONFIGURE_AVCS_FOR_FAILOVER = 'configure-avcs-for-failover'
 CHECK_VRRP_STATUS = 'check-vrrp-status'
 CHECK_VRRP_MASTER_STATUS = 'check-vrrp-master-status'
 CHECK_VRRP_BACKUP_STATUS = 'check-vrrp-backup-status'
 CONFIRM_VRRP_STATUS = 'confirm-vrrp-status'
 ADD_VRRP_SET_ID_INDB = 'add-vrrp-set-id-db'
 DELETE_VRRP_SET_ID_INDB = 'delete-vrrp-set-id-db'
+GET_VRRP_SET_ID_INDB = 'get-vrrp-set-id-db'
 ALLOCATE_VIP = 'allocate-vip'
 UPDATE_VIP_AFTER_ALLOCATION = 'update-vip-after-allocation'
 ALLOW_L2DSR = 'allow-l2dsr'
@@ -159,6 +182,8 @@ WAIT_FOR_BACKUP_VCS_RELOAD = 'wait-for-backup-vcs-reload'
 VCS_SYNC_WAIT = "wait-for-vcs_ready"
 GET_COMPUTE_FOR_PROJECT = 'get-compute-for-project'
 VALIDATE_COMPUTE_FOR_PROJECT = 'validate-compute-for-project'
+GET_SPARE_COMPUTE_FOR_PROJECT = 'get-spare-compute-for-project'
+DELETE_STALE_SPARE_VTHUNDER = 'delete-stale-spare-vthunder'
 CREATE_VTHUNDER_ENTRY = 'create-vthunder-entry'
 UPDATE_ACOS_VERSION_IN_VTHUNDER_ENTRY = 'update-acos-version-in-vthunder-entry'
 UPDATE_ACOS_VERSION_FOR_BACKUP_VTHUNDER = 'update-acos-version-for-backup-vthunder'
@@ -171,6 +196,8 @@ CREATE_SSL_CERT_FLOW = 'create-ssl-cert-flow'
 DELETE_SSL_CERT_FLOW = 'delete-ssl-cert-flow'
 LISTENER_TYPE_DECIDER_FLOW = 'listener_type_decider_flow'
 DELETE_LOADBALANCER_VRID_SUBFLOW = 'delete-loadbalancer-vrid-subflow'
+REVOKE_ACTIVE_VTHUNDER_LICENSE = 'revoke-active-vthunder-license'
+REVOKE_BACKUP_VTHUNDER_LICENSE = 'revoke-backup-vthunder-license'
 HANDLE_VRID_LOADBALANCER_SUBFLOW = 'handle-vrid-loadbalancer-subflow'
 CREATE_MEMBER_SNAT_POOL_SUBFLOW = 'create-member-snat-pool-subflow'
 DELETE_MEMBER_VTHUNDER_INTERNAL_SUBFLOW = 'delete-member-vthunder-internal-subflow'
@@ -182,16 +209,39 @@ DELETE_HEALTH_MONITOR_SUBFLOW_WITH_POOL_DELETE_FLOW = 'delete-health-monitor-sub
 DELETE_MEMBERS_SUBFLOW_WITH_POOL_DELETE_FLOW = 'delete-members-subflow-with-pool-delete-flow'
 HANDLE_VRID_MEMBER_SUBFLOW = 'handle-vrid-member-subflow'
 SPARE_VTHUNDER_CREATE = 'spare-vthunder-create'
+ACTIVATE_GLM_LICENSE_SUBFLOW = 'activate-glm-license-subflow'
+CONFIGURE_DNS_NAMESERVERS = 'configure-dns-nameservers'
+ACTIVATE_FLEXPOOL_LICENSE = 'activate-flexpool-license'
+CONFIGURE_PROXY_SERVER = 'configure-proxy-server'
+SET_VTHUNDER_HOSTNAME = 'set-vthunder-hostname'
 WRITE_MEMORY_THUNDER_FLOW = 'write-memory-thunder-flow'
 RELOAD_CHECK_THUNDER_FLOW = 'reload-check-thunder-flow'
 LB_TO_VTHUNDER_SUBFLOW = 'lb-to-vthunder-subflow'
+GET_SPARE_AMPHORA_SBUFLOW = 'get-sapre_amphora-subflow'
 GET_LB_RESOURCE = 'get-lb-resource'
 GET_LB_RESOURCE_SUBNET = 'get-lb-resource-subnet'
 GET_PROJECT_COUNT = 'get-child-parent-project-count'
 GET_LB_COUNT_SUBNET = 'get-lb-count-by-subnet'
+UPDATE_LISTENER_STATS_FLOW = 'update-listener-stats-flow'
+GET_VTHUNDER_AMPHORA = 'get-vthunder-amphora'
+COMPUTE_DELETE = 'compute-delete'
+SET_VTHUNDER_TO_STANDBY = 'set-vthunder-to-standby'
+GET_LBS_BY_THUNDER = 'get-loadbalancers-by-thunder'
+MARK_LB_PENIND_UPDATE_IN_DB = 'mark-vthunder-pending-update-in-db'
+MARK_LB_ACTIVE_IN_DB = 'mark-vthunder-active-in-db'
+GET_VTHUNDER_NETWORK_LIST = 'get-vthunder-network-list'
+GET_AMPHORA_FOR_FAILOVER = 'get-amphora-for-failover'
+PLUG_NETWORK_BY_IDS = 'plug-network-by-ids'
+PLUG_VIP_NETWORK_ON_SPARE = 'plusg-vip-network-on-spare'
+POST_SPARE_PLUG_NETWORK = 'post-failover-plug-network'
+GET_VCS_DEVICE_ID = 'get-vcs-device-id'
+POST_FAILOVER_DB_UPDATE = 'post-failover-db-update'
+MARK_LB_LIST_ERROR_ON_REVERT = 'mark-lb-list-error-on-revert'
 
 # ======================
 # Non-Taskflow Constants
 # ======================
 
 OCTAVIA_OWNER = 'Octavia'
+TOPOLOGY_SPARE = 'SPARE'
+READY = "READY"
