@@ -44,14 +44,14 @@ from a10_octavia.db import repositories as a10repo
 
 urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
 
-RETRY_ATTEMPTS = 15
-RETRY_INITIAL_DELAY = 1
-RETRY_BACKOFF = 1
-RETRY_MAX = 5
-
 CONF = cfg.CONF
 LOG = logging.getLogger(__name__)
 
+RETRY_ATTEMPTS = CONF.a10_controller_worker.retry_attempts
+RETRY_INITIAL_DELAY = CONF.a10_controller_worker.retry_initial_delay
+RETRY_BACKOFF = CONF.a10_controller_worker.retry_bakcoff
+RETRY_MAX = CONF.a10_controller_worker.retry_max
+
 
 def ctx_cnt_dec(ctx_lock, ctx_map, key, is_reload_thread, flags):
     LOG.debug('--------------------------ctx_cnt_dec-----------------------------')
@@ -132,13 +132,13 @@ class A10ControllerWorker(base_taskflow.BaseTaskFlowEngine):
 
         :returns: amphora_id
         """
-        create_vthunder_tf = self._taskflow_load(
+        create_vthunder_tf = self.taskflow_load(
             self._vthunder_flows.get_create_vthunder_flow(),
             store={constants.BUILD_TYPE_PRIORITY:
-                   constants.LB_CREATE_SPARES_POOL_PRIORITY}
+                   constants.LB_CREATE_SPARES_POOL_PRIORITY,
+                   constants.FLAVOR: None}
         )
         with tf_logging.DynamicLoggingListener(create_vthunder_tf, log=LOG):
-
             create_vthunder_tf.run()
 
         return create_vthunder_tf.storage.fetch('amphora')
@@ -161,7 +161,6 @@ class A10ControllerWorker(base_taskflow.BaseTaskFlowEngine):
             LOG.warning('Failed to fetch %s %s from DB. Retrying for up to '
                         '60 seconds.', 'health_monitor', health_monitor_id)
             raise db_exceptions.NoResultFound
-
         pool = health_mon.pool
         listeners = pool.listeners
         pool.health_monitor = health_mon
@@ -173,7 +172,7 @@ class A10ControllerWorker(base_taskflow.BaseTaskFlowEngine):
         # rack flow _vthunder_busy_check() will always return False
         busy = self._vthunder_busy_check(health_mon.project_id, False, ctx_flags, load_balancer)
         try:
-            create_hm_tf = self._taskflow_load(
+            create_hm_tf = self.taskflow_load(
                 self._health_monitor_flows.get_create_health_monitor_flow(topology=topology),
                 store={constants.HEALTH_MON: health_mon,
                        constants.POOL: pool,
@@ -209,7 +208,7 @@ class A10ControllerWorker(base_taskflow.BaseTaskFlowEngine):
         # rack flow _vthunder_busy_check() will always return False
         busy = self._vthunder_busy_check(health_mon.project_id, False, ctx_flags, load_balancer)
         try:
-            delete_hm_tf = self._taskflow_load(
+            delete_hm_tf = self.taskflow_load(
                 self._health_monitor_flows.get_delete_health_monitor_flow(topology=topology),
                 store={constants.HEALTH_MON: health_mon,
                        constants.POOL: pool,
@@ -256,7 +255,7 @@ class A10ControllerWorker(base_taskflow.BaseTaskFlowEngine):
         # rack flow _vthunder_busy_check() will always return False
         busy = self._vthunder_busy_check(health_mon.project_id, False, ctx_flags, load_balancer)
         try:
-            update_hm_tf = self._taskflow_load(
+            update_hm_tf = self.taskflow_load(
                 self._health_monitor_flows.get_update_health_monitor_flow(topology=topology),
                 store={constants.HEALTH_MON: health_mon,
                        constants.POOL: pool,
@@ -280,14 +279,12 @@ class A10ControllerWorker(base_taskflow.BaseTaskFlowEngine):
         stop=tenacity.stop_after_attempt(RETRY_ATTEMPTS))
     def create_listener(self, listener_id):
         """Function to create listener for A10 provider"""
-
         listener = self._listener_repo.get(db_apis.get_session(),
                                            id=listener_id)
         if not listener:
             LOG.warning('Failed to fetch %s %s from DB. Retrying for up to '
                         '60 seconds.', 'listener', listener_id)
             raise db_exceptions.NoResultFound
-
         load_balancer = listener.load_balancer
         parent_project_list = utils.get_parent_project_list()
         listener_parent_proj = utils.get_parent_project(listener.project_id)
@@ -299,17 +296,15 @@ class A10ControllerWorker(base_taskflow.BaseTaskFlowEngine):
             if (listener.project_id in parent_project_list or
                     (listener_parent_proj and listener_parent_proj in parent_project_list)
                     or self._is_rack_flow(listener.project_id, loadbalancer=load_balancer)):
-                create_listener_tf = self._taskflow_load(self._listener_flows.
-                                                         get_rack_vthunder_create_listener_flow(
-                                                             listener.project_id),
-                                                         store={constants.LOADBALANCER:
-                                                                load_balancer,
-                                                                constants.LISTENER:
-                                                                listener})
+                create_listener_tf = self.taskflow_load(
+                    self._listener_flows.get_rack_vthunder_create_listener_flow(
+                        listener.project_id),
+                    store={constants.LOADBALANCER: load_balancer,
+                           constants.LISTENER: listener})
             else:
                 busy = self._vthunder_busy_check(listener.project_id, False, ctx_flags,
                                                  load_balancer)
-                create_listener_tf = self._taskflow_load(
+                create_listener_tf = self.taskflow_load(
                     self._listener_flows.get_create_listener_flow(topology=topology),
                     store={constants.LOADBALANCER: load_balancer,
                            a10constants.COMPUTE_BUSY: busy,
@@ -335,14 +330,14 @@ class A10ControllerWorker(base_taskflow.BaseTaskFlowEngine):
         ctx_flags = [False]
         try:
             if self._is_rack_flow(listener.project_id, loadbalancer=load_balancer):
-                delete_listener_tf = self._taskflow_load(
+                delete_listener_tf = self.taskflow_load(
                     self._listener_flows.get_delete_rack_listener_flow(),
                     store={constants.LOADBALANCER: load_balancer,
                            constants.LISTENER: listener})
             else:
                 busy = self._vthunder_busy_check(listener.project_id, False, ctx_flags,
                                                  load_balancer)
-                delete_listener_tf = self._taskflow_load(
+                delete_listener_tf = self.taskflow_load(
                     self._listener_flows.get_delete_listener_flow(topology),
                     store={constants.LOADBALANCER: load_balancer,
                            a10constants.COMPUTE_BUSY: busy,
@@ -378,16 +373,12 @@ class A10ControllerWorker(base_taskflow.BaseTaskFlowEngine):
         # rack flow _vthunder_busy_check() will always return False
         busy = self._vthunder_busy_check(listener.project_id, False, ctx_flags, load_balancer)
         try:
-            update_listener_tf = self._taskflow_load(self._listener_flows.
-                                                     get_update_listener_flow(topology),
-                                                     store={constants.LISTENER:
-                                                            listener,
-                                                            a10constants.COMPUTE_BUSY: busy,
-                                                            constants.LOADBALANCER:
-                                                                load_balancer,
-                                                            constants.UPDATE_DICT:
-                                                                listener_updates
-                                                            })
+            update_listener_tf = self.taskflow_load(
+                self._listener_flows.get_update_listener_flow(topology),
+                store={constants.LISTENER: listener,
+                       a10constants.COMPUTE_BUSY: busy,
+                       constants.LOADBALANCER: load_balancer,
+                       constants.UPDATE_DICT: listener_updates})
             self._register_flow_notify_handler(update_listener_tf, listener.project_id, False,
                                                busy, ctx_flags, load_balancer)
             with tf_logging.DynamicLoggingListener(update_listener_tf, log=LOG):
@@ -402,7 +393,6 @@ class A10ControllerWorker(base_taskflow.BaseTaskFlowEngine):
         stop=tenacity.stop_after_attempt(RETRY_ATTEMPTS))
     def create_load_balancer(self, load_balancer_id, flavor=None, ctx_map=None, ctx_lock=None):
         """Function to create load balancer for A10 provider"""
-
         lb = self._lb_repo.get(db_apis.get_session(), id=load_balancer_id)
         if not lb:
             LOG.warning('Failed to fetch %s %s from DB. Retrying for up to '
@@ -424,7 +414,7 @@ class A10ControllerWorker(base_taskflow.BaseTaskFlowEngine):
 
         store[constants.UPDATE_DICT] = {
             constants.TOPOLOGY: topology,
-            a10constants.FLAVOR_ID: flavor_id
+            constants.FLAVOR_ID: flavor_id
         }
 
         ctx_flags = [False]
@@ -435,7 +425,7 @@ class A10ControllerWorker(base_taskflow.BaseTaskFlowEngine):
                 create_lb_flow = self._lb_flows.get_create_rack_vthunder_load_balancer_flow(
                     vthunder_conf=vthunder_conf, device_dict=device_dict,
                     topology=topology, listeners=lb.listeners)
-                create_lb_tf = self._taskflow_load(create_lb_flow, store=store)
+                create_lb_tf = self.taskflow_load(create_lb_flow, store=store)
             else:
                 busy = self._vthunder_busy_check(lb.project_id, True, ctx_flags, lb, store)
                 create_lb_flow = self._lb_flows.get_create_load_balancer_flow(
@@ -444,7 +434,7 @@ class A10ControllerWorker(base_taskflow.BaseTaskFlowEngine):
                     (a10constants.COMPUTE_BUSY, busy),
                     (a10constants.VTHUNDER_CONFIG, None),
                     (a10constants.USE_DEVICE_FLAVOR, False)])
-                create_lb_tf = self._taskflow_load(create_lb_flow, store=store)
+                create_lb_tf = self.taskflow_load(create_lb_flow, store=store)
                 self._register_flow_notify_handler(create_lb_tf, lb.project_id, True,
                                                    busy, ctx_flags, lb)
 
@@ -488,12 +478,14 @@ class A10ControllerWorker(base_taskflow.BaseTaskFlowEngine):
                               a10constants.COMPUTE_BUSY: busy,
                               constants.VIP: lb.vip,
                               constants.SERVER_GROUP_ID: lb.server_group_id,
+                              constants.LOADBALANCER_ID: lb.id,
+                              a10constants.MASTER_AMPHORA_STATUS: True,
                               a10constants.VTHUNDER_CONFIG: None,
                               a10constants.USE_DEVICE_FLAVOR: False,
                               a10constants.LB_COUNT_THUNDER: None,
                               a10constants.MEMBER_COUNT_THUNDER: None})
 
-            delete_lb_tf = self._taskflow_load(flow, store=store)
+            delete_lb_tf = self.taskflow_load(flow, store=store)
             self._register_flow_notify_handler(delete_lb_tf, lb.project_id, True, busy,
                                                ctx_flags, lb)
 
@@ -529,7 +521,7 @@ class A10ControllerWorker(base_taskflow.BaseTaskFlowEngine):
             if self._is_rack_flow(lb.project_id, loadbalancer=lb):
                 vthunder_conf = CONF.hardware_thunder.devices.get(lb.project_id, None)
                 device_dict = CONF.hardware_thunder.devices
-                update_lb_tf = self._taskflow_load(
+                update_lb_tf = self.taskflow_load(
                     self._lb_flows.get_update_rack_load_balancer_flow(vthunder_conf=vthunder_conf,
                                                                       device_dict=device_dict,
                                                                       topology=topology),
@@ -539,7 +531,7 @@ class A10ControllerWorker(base_taskflow.BaseTaskFlowEngine):
                            constants.UPDATE_DICT: load_balancer_updates})
             else:
                 busy = self._vthunder_busy_check(lb.project_id, False, ctx_flags, lb)
-                update_lb_tf = self._taskflow_load(
+                update_lb_tf = self.taskflow_load(
                     self._lb_flows.get_update_load_balancer_flow(topology=topology),
                     store={constants.LOADBALANCER: lb,
                            constants.LOADBALANCER_ID: lb.id,
@@ -594,7 +586,7 @@ class A10ControllerWorker(base_taskflow.BaseTaskFlowEngine):
                     or self._is_rack_flow(member.project_id, loadbalancer=load_balancer)):
                 vthunder_conf = CONF.hardware_thunder.devices.get(load_balancer.project_id, None)
                 device_dict = CONF.hardware_thunder.devices
-                create_member_tf = self._taskflow_load(
+                create_member_tf = self.taskflow_load(
                     self._member_flows.get_rack_vthunder_create_member_flow(
                         vthunder_conf=vthunder_conf, device_dict=device_dict),
                     store={
@@ -604,7 +596,7 @@ class A10ControllerWorker(base_taskflow.BaseTaskFlowEngine):
                         constants.POOL: pool})
             else:
                 busy = self._vthunder_busy_check(member.project_id, True, ctx_flags, load_balancer)
-                create_member_tf = self._taskflow_load(
+                create_member_tf = self.taskflow_load(
                     self._member_flows.get_create_member_flow(topology=topology),
                     store={constants.MEMBER: member,
                            constants.LISTENERS:
@@ -614,7 +606,8 @@ class A10ControllerWorker(base_taskflow.BaseTaskFlowEngine):
                            a10constants.COMPUTE_BUSY: busy,
                            constants.POOL: pool,
                            a10constants.VTHUNDER_CONFIG: None,
-                           a10constants.USE_DEVICE_FLAVOR: False})
+                           a10constants.USE_DEVICE_FLAVOR: False,
+                           constants.LOADBALANCER_ID: load_balancer.id})
                 self._register_flow_notify_handler(create_member_tf, member.project_id, True,
                                                    busy, ctx_flags, load_balancer)
 
@@ -643,7 +636,7 @@ class A10ControllerWorker(base_taskflow.BaseTaskFlowEngine):
             if self._is_rack_flow(member.project_id, loadbalancer=load_balancer):
                 vthunder_conf = CONF.hardware_thunder.devices.get(load_balancer.project_id, None)
                 device_dict = CONF.hardware_thunder.devices
-                delete_member_tf = self._taskflow_load(
+                delete_member_tf = self.taskflow_load(
                     self._member_flows.get_rack_vthunder_delete_member_flow(
                         vthunder_conf=vthunder_conf, device_dict=device_dict),
                     store={constants.MEMBER: member, constants.LISTENERS: listeners,
@@ -651,14 +644,15 @@ class A10ControllerWorker(base_taskflow.BaseTaskFlowEngine):
                 )
             else:
                 busy = self._vthunder_busy_check(member.project_id, True, ctx_flags, load_balancer)
-                delete_member_tf = self._taskflow_load(
+                delete_member_tf = self.taskflow_load(
                     self._member_flows.get_delete_member_flow(topology=topology),
                     store={constants.MEMBER: member, constants.LISTENERS: listeners,
                            constants.LOADBALANCER: load_balancer, a10constants.COMPUTE_BUSY: busy,
                            constants.POOL: pool, a10constants.VTHUNDER_CONFIG: None,
                            a10constants.USE_DEVICE_FLAVOR: False,
                            a10constants.LB_COUNT_THUNDER: None,
-                           a10constants.MEMBER_COUNT_THUNDER: None}
+                           a10constants.MEMBER_COUNT_THUNDER: None,
+                           constants.LOADBALANCER_ID: load_balancer.id}
                 )
                 self._register_flow_notify_handler(delete_member_tf, member.project_id, True,
                                                    busy, ctx_flags, load_balancer)
@@ -740,10 +734,8 @@ class A10ControllerWorker(base_taskflow.BaseTaskFlowEngine):
         updated_member_ids = [m.get('id') for m in updated_members_req]
         updated_member_models = [self._member_repo.get(db_apis.get_session(), id=mid)
                                  for mid in updated_member_ids]
-
         old_members = [self._member_repo.get(db_apis.get_session(), id=mid)
                        for mid in old_member_ids]
-
         new_members = [self._member_repo.get(db_apis.get_session(), id=mid)
                        for mid in new_member_ids]
 
@@ -753,9 +745,8 @@ class A10ControllerWorker(base_taskflow.BaseTaskFlowEngine):
             pool = new_members[0].pool
         else:
             pool = updated_member_models[0].pool
-
-        load_balancer = pool.load_balancer
         listeners = pool.listeners
+        load_balancer = pool.load_balancer
 
         modified_members = old_members + updated_member_models + new_members
         member_collision_map = {}
@@ -793,7 +784,7 @@ class A10ControllerWorker(base_taskflow.BaseTaskFlowEngine):
             if self._is_rack_flow(pool.project_id, loadbalancer=load_balancer):
                 vthunder_conf = CONF.hardware_thunder.devices.get(load_balancer.project_id, None)
                 device_dict = CONF.hardware_thunder.devices
-                batch_update_members_tf = self._taskflow_load(
+                batch_update_members_tf = self.taskflow_load(
                     self._member_flows.get_rack_vthunder_batch_update_members_flow(
                         old_members, new_members, updated_members,
                         vthunder_conf, device_dict),
@@ -804,13 +795,14 @@ class A10ControllerWorker(base_taskflow.BaseTaskFlowEngine):
                 topology = CONF.a10_controller_worker.loadbalancer_topology
                 busy = self._vthunder_busy_check(load_balancer.project_id, True,
                                                  ctx_flags, load_balancer)
-                batch_update_members_tf = self._taskflow_load(
+                batch_update_members_tf = self.taskflow_load(
                     self._member_flows.get_batch_update_members_flow(
                         old_members, new_members, updated_members, topology),
                     store={constants.LISTENERS: listeners,
                            constants.LOADBALANCER: load_balancer,
                            a10constants.COMPUTE_BUSY: busy,
                            constants.POOL: pool,
+                           constants.LOADBALANCER_ID: load_balancer.id,
                            a10constants.VTHUNDER_CONFIG: None,
                            a10constants.USE_DEVICE_FLAVOR: False,
                            a10constants.LB_COUNT_THUNDER: None,
@@ -819,7 +811,6 @@ class A10ControllerWorker(base_taskflow.BaseTaskFlowEngine):
                 self._register_flow_notify_handler(batch_update_members_tf,
                                                    load_balancer.project_id, True,
                                                    busy, ctx_flags, load_balancer)
-
             with tf_logging.DynamicLoggingListener(batch_update_members_tf,
                                                    log=LOG):
                 batch_update_members_tf.run()
@@ -857,7 +848,7 @@ class A10ControllerWorker(base_taskflow.BaseTaskFlowEngine):
             if self._is_rack_flow(member.project_id, loadbalancer=load_balancer):
                 vthunder_conf = CONF.hardware_thunder.devices.get(load_balancer.project_id, None)
                 device_dict = CONF.hardware_thunder.devices
-                update_member_tf = self._taskflow_load(
+                update_member_tf = self.taskflow_load(
                     self._member_flows.get_rack_vthunder_update_member_flow(
                         vthunder_conf=vthunder_conf, device_dict=device_dict),
                     store={constants.MEMBER: member,
@@ -868,7 +859,7 @@ class A10ControllerWorker(base_taskflow.BaseTaskFlowEngine):
             else:
                 busy = self._vthunder_busy_check(member.project_id, False, ctx_flags,
                                                  load_balancer)
-                update_member_tf = self._taskflow_load(
+                update_member_tf = self.taskflow_load(
                     self._member_flows.get_update_member_flow(topology=topology),
                     store={constants.MEMBER: member,
                            constants.LISTENERS: listeners,
@@ -919,15 +910,13 @@ class A10ControllerWorker(base_taskflow.BaseTaskFlowEngine):
         # rack flow _vthunder_busy_check() will always return False
         busy = self._vthunder_busy_check(pool.project_id, False, ctx_flags, load_balancer)
         try:
-            create_pool_tf = self._taskflow_load(self._pool_flows.
-                                                 get_create_pool_flow(topology=topology),
-                                                 store={constants.POOL: pool,
-                                                        constants.LISTENERS:
-                                                            listeners,
-                                                        constants.LISTENER: default_listener,
-                                                        constants.LOADBALANCER:
-                                                            load_balancer,
-                                                        a10constants.COMPUTE_BUSY: busy})
+            create_pool_tf = self.taskflow_load(
+                self._pool_flows.get_create_pool_flow(topology=topology),
+                store={constants.POOL: pool,
+                       constants.LISTENERS: listeners,
+                       constants.LISTENER: default_listener,
+                       constants.LOADBALANCER: load_balancer,
+                       a10constants.COMPUTE_BUSY: busy})
             self._register_flow_notify_handler(create_pool_tf, pool.project_id, False,
                                                busy, ctx_flags, load_balancer)
             with tf_logging.DynamicLoggingListener(create_pool_tf,
@@ -961,7 +950,8 @@ class A10ControllerWorker(base_taskflow.BaseTaskFlowEngine):
                  constants.LISTENER: default_listener,
                  constants.LOADBALANCER: load_balancer,
                  constants.HEALTH_MON: health_monitor,
-                 a10constants.MEMBER_COUNT: mem_count}
+                 a10constants.MEMBER_COUNT: mem_count,
+                 constants.LOADBALANCER_ID: load_balancer.id}
 
         ctx_flags = [False]
         try:
@@ -970,7 +960,7 @@ class A10ControllerWorker(base_taskflow.BaseTaskFlowEngine):
                 device_dict = CONF.hardware_thunder.devices
                 store.update([(a10constants.VTHUNDER_CONFIG, vthunder_conf),
                               (a10constants.DEVICE_CONFIG_DICT, device_dict)])
-                delete_pool_tf = self._taskflow_load(
+                delete_pool_tf = self.taskflow_load(
                     self._pool_flows.get_delete_pool_rack_flow(
                         members, health_monitor, store), store=store)
             else:
@@ -979,7 +969,7 @@ class A10ControllerWorker(base_taskflow.BaseTaskFlowEngine):
                               a10constants.POOLS: None})
                 busy = self._vthunder_busy_check(pool.project_id, False, ctx_flags,
                                                  load_balancer, store)
-                delete_pool_tf = self._taskflow_load(
+                delete_pool_tf = self.taskflow_load(
                     self._pool_flows.get_delete_pool_flow(
                         members, health_monitor, store, topology), store=store)
                 self._register_flow_notify_handler(delete_pool_tf, pool.project_id, False,
@@ -1024,17 +1014,14 @@ class A10ControllerWorker(base_taskflow.BaseTaskFlowEngine):
         # rack flow _vthunder_busy_check() will always return False
         busy = self._vthunder_busy_check(pool.project_id, False, ctx_flags, load_balancer)
         try:
-            update_pool_tf = self._taskflow_load(self._pool_flows.
-                                                 get_update_pool_flow(topology),
-                                                 store={constants.POOL: pool,
-                                                        constants.LISTENERS:
-                                                            listeners,
-                                                        constants.LISTENER: default_listener,
-                                                        constants.LOADBALANCER:
-                                                            load_balancer,
-                                                        a10constants.COMPUTE_BUSY: busy,
-                                                        constants.UPDATE_DICT:
-                                                            pool_updates})
+            update_pool_tf = self.taskflow_load(
+                self._pool_flows.get_update_pool_flow(topology),
+                store={constants.POOL: pool,
+                       constants.LISTENERS: listeners,
+                       constants.LISTENER: default_listener,
+                       constants.LOADBALANCER: load_balancer,
+                       a10constants.COMPUTE_BUSY: busy,
+                       constants.UPDATE_DICT: pool_updates})
             self._register_flow_notify_handler(update_pool_tf, pool.project_id, False,
                                                busy, ctx_flags, load_balancer)
             with tf_logging.DynamicLoggingListener(update_pool_tf,
@@ -1061,7 +1048,6 @@ class A10ControllerWorker(base_taskflow.BaseTaskFlowEngine):
             LOG.warning('Failed to fetch %s %s from DB. Retrying for up to '
                         '60 seconds.', 'l7policy', l7policy_id)
             raise db_exceptions.NoResultFound
-
         listeners = [l7policy.listener]
         load_balancer = l7policy.listener.load_balancer
 
@@ -1071,7 +1057,7 @@ class A10ControllerWorker(base_taskflow.BaseTaskFlowEngine):
         # rack flow _vthunder_busy_check() will always return False
         busy = self._vthunder_busy_check(l7policy.project_id, False, ctx_flags, load_balancer)
         try:
-            create_l7policy_tf = self._taskflow_load(
+            create_l7policy_tf = self.taskflow_load(
                 self._l7policy_flows.get_create_l7policy_flow(topology=topology),
                 store={constants.L7POLICY: l7policy,
                        constants.LISTENERS: listeners,
@@ -1103,7 +1089,7 @@ class A10ControllerWorker(base_taskflow.BaseTaskFlowEngine):
         # rack flow _vthunder_busy_check() will always return False
         busy = self._vthunder_busy_check(l7policy.project_id, False, ctx_flags, load_balancer)
         try:
-            delete_l7policy_tf = self._taskflow_load(
+            delete_l7policy_tf = self.taskflow_load(
                 self._l7policy_flows.get_delete_l7policy_flow(topology=topology),
                 store={constants.L7POLICY: l7policy,
                        constants.LISTENERS: listeners,
@@ -1147,7 +1133,7 @@ class A10ControllerWorker(base_taskflow.BaseTaskFlowEngine):
         # rack flow _vthunder_busy_check() will always return False
         busy = self._vthunder_busy_check(l7policy.project_id, False, ctx_flags, load_balancer)
         try:
-            update_l7policy_tf = self._taskflow_load(
+            update_l7policy_tf = self.taskflow_load(
                 self._l7policy_flows.get_update_l7policy_flow(topology=topology),
                 store={constants.L7POLICY: l7policy,
                        constants.LISTENERS: listeners,
@@ -1180,7 +1166,6 @@ class A10ControllerWorker(base_taskflow.BaseTaskFlowEngine):
             LOG.warning('Failed to fetch %s %s from DB. Retrying for up to '
                         '60 seconds.', 'l7rule', l7rule_id)
             raise db_exceptions.NoResultFound
-
         l7policy = l7rule.l7policy
         listeners = [l7policy.listener]
         load_balancer = l7policy.listener.load_balancer
@@ -1191,7 +1176,7 @@ class A10ControllerWorker(base_taskflow.BaseTaskFlowEngine):
         # rack flow _vthunder_busy_check() will always return False
         busy = self._vthunder_busy_check(l7rule.project_id, False, ctx_flags, load_balancer)
         try:
-            create_l7rule_tf = self._taskflow_load(
+            create_l7rule_tf = self.taskflow_load(
                 self._l7rule_flows.get_create_l7rule_flow(topology=topology),
                 store={constants.L7RULE: l7rule,
                        constants.L7POLICY: l7policy,
@@ -1224,7 +1209,7 @@ class A10ControllerWorker(base_taskflow.BaseTaskFlowEngine):
         # rack flow _vthunder_busy_check() will always return False
         busy = self._vthunder_busy_check(l7rule.project_id, False, ctx_flags, load_balancer)
         try:
-            delete_l7rule_tf = self._taskflow_load(
+            delete_l7rule_tf = self.taskflow_load(
                 self._l7rule_flows.get_delete_l7rule_flow(topology=topology),
                 store={constants.L7RULE: l7rule,
                        constants.L7POLICY: l7policy,
@@ -1269,7 +1254,7 @@ class A10ControllerWorker(base_taskflow.BaseTaskFlowEngine):
         # rack flow _vthunder_busy_check() will always return False
         busy = self._vthunder_busy_check(l7rule.project_id, False, ctx_flags, load_balancer)
         try:
-            update_l7rule_tf = self._taskflow_load(
+            update_l7rule_tf = self.taskflow_load(
                 self._l7rule_flows.get_update_l7rule_flow(topology=topology),
                 store={constants.L7RULE: l7rule,
                        constants.L7POLICY: l7policy,
@@ -1285,50 +1270,6 @@ class A10ControllerWorker(base_taskflow.BaseTaskFlowEngine):
         finally:
             self._set_vthunder_available(l7rule.project_id, False, ctx_flags, load_balancer)
 
-    def _switch_roles_for_ha_flow(self, vthunder):
-        lock_session = db_apis.get_session(autocommit=False)
-        if vthunder.role == constants.ROLE_MASTER:
-            LOG.info("Master vThunder %s has failed, searching for existing backup vThunder.",
-                     vthunder.ip_address)
-            backup_vthunder = self._vthunder_repo.get_backup_vthunder_from_lb(
-                lock_session,
-                lb_id=vthunder.loadbalancer_id)
-            if backup_vthunder:
-                LOG.info("Making Backup vThunder %s as MASTER NOW",
-                         backup_vthunder.ip_address)
-                self._vthunder_repo.update(
-                    lock_session,
-                    backup_vthunder.id, role=constants.ROLE_MASTER)
-
-                LOG.info("Putting %s to failed vThunders",
-                         vthunder.ip_address)
-
-                self._vthunder_repo.update(
-                    lock_session,
-                    vthunder.id, role=constants.ROLE_BACKUP, status=a10constants.FAILED)
-
-                lock_session.commit()
-                LOG.info("vThunder %s's status is FAILED", vthunder.ip_address)
-                status = {'vthunders': [{"id": vthunder.vthunder_id,
-                                         "status": a10constants.FAILED,
-                                         "ip_address": vthunder.ip_address}]}
-                LOG.info(str(status))
-            else:
-                LOG.warning("No backup found for failed MASTER %s", vthunder.ip_address)
-
-        elif vthunder.role == constants.ROLE_BACKUP:
-            LOG.info("BACKUP vThunder %s has failed", vthunder.ip_address)
-            self._vthunder_repo.update(
-                lock_session,
-                vthunder.id, status=a10constants.FAILED)
-            LOG.info("vThunder %s's status is FAILED", vthunder.ip_address)
-            status = {'vthunders': [{"id": vthunder.vthunder_id,
-                                     "status": a10constants.FAILED,
-                                     "ip_address": vthunder.ip_address}]}
-            lock_session.commit()
-            LOG.info(str(status))
-        # TODO(ytsai-a10) check if we need to call lock_session.close() to release db lock
-
     def failover_amphora(self, vthunder_id):
         """Perform failover operations for an vThunder.
         :param vthunder_id: ID for vThunder to failover
@@ -1343,17 +1284,36 @@ class A10ControllerWorker(base_taskflow.BaseTaskFlowEngine):
                 return
 
             LOG.info("Starting Failover process on %s", vthunder.ip_address)
-            # feature : db role switching for HA flow
-            self._switch_roles_for_ha_flow(vthunder)
 
-            # TODO(hthompson6) delete failed one
-            # TODO(hthompson6) boot up new amps
-            # TODO(hthompson6) vrrp sync
+            store = {a10constants.VTHUNDER: vthunder,
+                     a10constants.FAILOVER_VTHUNDER: vthunder}
+            failover_tf = None
+            if vthunder.topology == a10constants.TOPOLOGY_SPARE:
+                failover_tf = self.taskflow_load(
+                    self._vthunder_flows.get_failover_spare_vthunder_flow(),
+                    store=store)
+            elif vthunder.topology == constants.TOPOLOGY_ACTIVE_STANDBY:
+                health_vthunder_count = self._vthunder_repo.get_health_vthunder_count_for_lb(
+                    db_apis.get_session(), vthunder.loadbalancer_id)
+                if health_vthunder_count > 0:
+                    failover_tf = self.taskflow_load(
+                        self._vthunder_flows.get_failover_vcs_vthunder_flow(),
+                        store=store)
+                else:
+                    LOG.warning("Failover for a total HA Pair failure is not supported. "
+                                "Pair will be kept in failed state.")
+                    failover_tf = self.taskflow_load(
+                        self._vthunder_flows.get_failover_restore_vthunder_flow(),
+                        store=store)
+
+            if failover_tf:
+                with tf_logging.DynamicLoggingListener(failover_tf, log=LOG):
+                    failover_tf.run()
 
         except Exception as e:
             with excutils.save_and_reraise_exception():
-                LOG.error("vThunder %(id)s failover exception: %(exc)s",
-                          {'id': vthunder_id, 'exc': e})
+                LOG.error("vThunder %(id)s topology %(topology)s failover exception: %(exc)s",
+                          {'id': vthunder_id, 'topology': vthunder.topology, 'exc': e})
 
     def failover_loadbalancer(self, load_balancer_id):
         """Perform failover operations for a load balancer.
@@ -1401,7 +1361,7 @@ class A10ControllerWorker(base_taskflow.BaseTaskFlowEngine):
                 delete_compute = self._vthunder_repo.get_delete_compute_flag(db_apis.get_session(),
                                                                              vthunder.compute_id)
             try:
-                write_mem_tf = self._taskflow_load(
+                write_mem_tf = self.taskflow_load(
                     self._vthunder_flows.get_write_memory_flow(vthunder, store, delete_compute),
                     store=store)
 
@@ -1421,7 +1381,7 @@ class A10ControllerWorker(base_taskflow.BaseTaskFlowEngine):
         store = {}
         for vthunder in thunders:
             try:
-                reload_check_tf = self._taskflow_load(
+                reload_check_tf = self.taskflow_load(
                     self._vthunder_flows.get_reload_check_flow(vthunder, store),
                     store=store)
                 with tf_logging.DynamicLoggingListener(reload_check_tf, log=LOG):
@@ -1430,6 +1390,24 @@ class A10ControllerWorker(base_taskflow.BaseTaskFlowEngine):
                 # continue on other thunders (assume exception is logged)
                 pass
 
+    def perform_vthunder_stats_update(self, ip):
+        """Perform for listener statistics update"""
+
+        store = {}
+        try:
+            thunders = self._vthunder_repo.get_all_vthunder_by_address(
+                db_apis.get_session(),
+                ip_address=ip)
+            for vthunder in thunders:
+                vthunder_stats_tf = self.taskflow_load(
+                    self._listener_flows.get_listener_stats_flow(vthunder, store),
+                    store=store)
+                with tf_logging.DynamicLoggingListener(vthunder_stats_tf, log=LOG):
+                    vthunder_stats_tf.run()
+        except Exception:
+            # continue on other thunders (assume exception is logged)
+            pass
+
     def a10_worker_ctx_init(self, ctx_map, ctx_lock):
         self.ctx_map = ctx_map
         self.ctx_lock = ctx_lock
