@@ -19,14 +19,16 @@ from taskflow.patterns import unordered_flow
 
 from octavia.common import constants
 from octavia.common import exceptions
-from octavia.controller.worker.flows import amphora_flows
-from octavia.controller.worker.flows import listener_flows
-from octavia.controller.worker.flows import member_flows
-from octavia.controller.worker.flows import pool_flows
-from octavia.controller.worker.tasks import compute_tasks
-from octavia.controller.worker.tasks import database_tasks
-from octavia.controller.worker.tasks import lifecycle_tasks
-from octavia.controller.worker.tasks import network_tasks
+
+
+from octavia.controller.worker.v1.flows import amphora_flows
+from octavia.controller.worker.v1.flows import listener_flows
+from octavia.controller.worker.v1.flows import member_flows
+from octavia.controller.worker.v1.flows import pool_flows
+from octavia.controller.worker.v1.tasks import compute_tasks
+from octavia.controller.worker.v1.tasks import database_tasks
+from octavia.controller.worker.v1.tasks import lifecycle_tasks
+from octavia.controller.worker.v1.tasks import network_tasks
 from octavia.db import api as db_apis
 from octavia.db import repositories as repo
 
@@ -38,6 +40,7 @@ from a10_octavia.controller.worker.flows import vthunder_flows
 from a10_octavia.controller.worker.tasks import a10_compute_tasks
 from a10_octavia.controller.worker.tasks import a10_database_tasks
 from a10_octavia.controller.worker.tasks import a10_network_tasks
+from a10_octavia.controller.worker.tasks import glm_tasks
 from a10_octavia.controller.worker.tasks import nat_pool_tasks
 from a10_octavia.controller.worker.tasks import virtual_server_tasks
 from a10_octavia.controller.worker.tasks import vthunder_tasks
@@ -85,10 +88,10 @@ class LoadBalancerFlows(object):
         # Attaching vThunder to LB in database
         if topology == constants.TOPOLOGY_ACTIVE_STANDBY:
             lb_create_flow.add(*self._create_active_standby_topology())
-            LOG.info("TOPOLOGY ===" + str(topology))
+            LOG.info("TOPOLOGY === " + str(topology))
         elif topology == constants.TOPOLOGY_SINGLE:
             lb_create_flow.add(*self._create_single_topology())
-            LOG.info("TOPOLOGY ===" + str(topology))
+            LOG.info("TOPOLOGY === " + str(topology))
         else:
             LOG.error("Unknown topology: %s.  Unable to build load balancer.",
                       topology)
@@ -98,7 +101,6 @@ class LoadBalancerFlows(object):
         post_amp_prefix = constants.POST_LB_AMP_ASSOCIATION_SUBFLOW
         vthunder = self._vthunder_repo.get_vthunder_by_project_id(db_apis.get_session(),
                                                                   project_id)
-
         lb_create_flow.add(a10_database_tasks.GetFlavorData(
             rebind={a10constants.LB_RESOURCE: constants.LOADBALANCER},
             provides=constants.FLAVOR_DATA))
@@ -123,16 +125,6 @@ class LoadBalancerFlows(object):
         lb_create_flow.add(a10_database_tasks.SetThunderUpdatedAt(
             requires=a10constants.VTHUNDER))
 
-        # For first LB, vcs just setup and need sync. config and reload vBlade severial times.
-        if not vthunder and topology == constants.TOPOLOGY_ACTIVE_STANDBY:
-            lb_create_flow.add(a10_database_tasks.GetBackupVThunderByLoadBalancer(
-                name="get-blade-thunder-for-checking",
-                requires=constants.LOADBALANCER,
-                provides=a10constants.BACKUP_VTHUNDER))
-            lb_create_flow.add(virtual_server_tasks.WaitVirtualServerReadyOnBlade(
-                requires=(constants.LOADBALANCER),
-                rebind={a10constants.VTHUNDER: a10constants.BACKUP_VTHUNDER}))
-
         return lb_create_flow
 
     def _create_single_topology(self):
@@ -184,11 +176,11 @@ class LoadBalancerFlows(object):
         new_LB_net_subflow = self.get_new_lb_networking_subflow(topology, vthunder)
         post_create_lb_flow.add(new_LB_net_subflow)
 
+        post_create_lb_flow.add(
+            vthunder_tasks.CreateHealthMonitorOnVThunder(
+                name=a10constants.CREATE_HEALTH_MONITOR_ON_VTHUNDER,
+                requires=a10constants.VTHUNDER))
         if not vthunder and topology == constants.TOPOLOGY_ACTIVE_STANDBY:
-            post_create_lb_flow.add(
-                vthunder_tasks.CreateHealthMonitorOnVThunder(
-                    name=a10constants.CREATE_HEALTH_MONITOR_ON_VTHUNDER_MASTER,
-                    requires=a10constants.VTHUNDER))
             vrrp_subflow = self.vthunder_flows.get_vrrp_subflow(prefix)
             post_create_lb_flow.add(vrrp_subflow)
 
@@ -215,9 +207,17 @@ class LoadBalancerFlows(object):
             requires=a10constants.COMPUTE_BUSY))
 
         delete_LB_flow.add(a10_database_tasks.GetVThunderByLoadBalancer(
-            requires=constants.LOADBALANCER,
+            requires=(constants.LOADBALANCER, a10constants.MASTER_AMPHORA_STATUS),
             provides=a10constants.VTHUNDER))
         if lb.topology == constants.TOPOLOGY_ACTIVE_STANDBY:
+            delete_LB_flow.add(a10_compute_tasks.CheckAmphoraStatus(
+                name="check-master-amphora-status",
+                requires=a10constants.VTHUNDER,
+                provides=a10constants.MASTER_AMPHORA_STATUS))
+            delete_LB_flow.add(a10_database_tasks.GetVThunderByLoadBalancer(
+                name="get-vthunder-on-the-basis-of-master-amphora-status",
+                requires=(constants.LOADBALANCER, a10constants.MASTER_AMPHORA_STATUS),
+                provides=a10constants.VTHUNDER))
             delete_LB_flow.add(vthunder_tasks.GetMasterVThunder(
                 name=a10constants.GET_MASTER_VTHUNDER,
                 requires=a10constants.VTHUNDER,
@@ -233,7 +233,7 @@ class LoadBalancerFlows(object):
             (pools_listeners_delete, store) = self._get_cascade_delete_pools_listeners_flow(lb)
             delete_LB_flow.add(pools_listeners_delete)
         delete_LB_flow.add(database_tasks.GetAmphoraeFromLoadbalancer(
-            requires=constants.LOADBALANCER,
+            requires=constants.LOADBALANCER_ID,
             provides=constants.AMPHORA))
         delete_LB_flow.add(a10_database_tasks.GetLoadBalancerListForDeletion(
             requires=(a10constants.VTHUNDER, constants.LOADBALANCER),
@@ -242,37 +242,52 @@ class LoadBalancerFlows(object):
             delete_LB_flow.add(a10_database_tasks.GetBackupVThunderByLoadBalancer(
                 requires=(constants.LOADBALANCER, a10constants.VTHUNDER),
                 provides=a10constants.BACKUP_VTHUNDER))
+            delete_LB_flow.add(a10_compute_tasks.CheckAmphoraStatus(
+                name="check-master-amphora-status-after_getting-backup",
+                requires=a10constants.VTHUNDER,
+                provides=a10constants.MASTER_AMPHORA_STATUS))
+            delete_LB_flow.add(a10_compute_tasks.CheckAmphoraStatus(
+                name="check-backup-amphora-status",
+                rebind={a10constants.VTHUNDER: a10constants.BACKUP_VTHUNDER},
+                provides=a10constants.BACKUP_AMPHORA_STATUS))
+
         if not deleteCompute:
+            delete_LB_flow.add(a10_database_tasks.GetMemberListByProjectID(
+                requires=a10constants.VTHUNDER,
+                provides=a10constants.MEMBER_LIST))
             delete_LB_flow.add(a10_network_tasks.CalculateDelta(
-                requires=(constants.LOADBALANCER, a10constants.LOADBALANCERS_LIST),
+                requires=(constants.LOADBALANCER, a10constants.LOADBALANCERS_LIST,
+                          a10constants.MEMBER_LIST),
                 provides=constants.DELTAS))
             delete_LB_flow.add(a10_network_tasks.HandleNetworkDeltas(
                 requires=constants.DELTAS, provides=constants.ADDED_PORTS))
+            if lb.topology == "ACTIVE_STANDBY":
+                delete_LB_flow.add(vthunder_tasks.VCSSyncWait(
+                    name="wait-vcs-ready-before-master-reload",
+                    requires=(a10constants.VTHUNDER,
+                              a10constants.MASTER_AMPHORA_STATUS,
+                              a10constants.BACKUP_AMPHORA_STATUS)))
             delete_LB_flow.add(vthunder_tasks.AmphoraePostNetworkUnplug(
                 name=a10constants.AMPHORA_POST_NETWORK_UNPLUG,
                 requires=(constants.LOADBALANCER, constants.ADDED_PORTS, a10constants.VTHUNDER)))
             delete_LB_flow.add(
                 vthunder_tasks.VThunderComputeConnectivityWait(
                     name=a10constants.VTHUNDER_CONNECTIVITY_WAIT,
-                    requires=(a10constants.VTHUNDER, constants.AMPHORA)))
+                    requires=(a10constants.VTHUNDER, constants.AMPHORA,
+                              a10constants.MASTER_AMPHORA_STATUS)))
             if lb.topology == "ACTIVE_STANDBY":
-                delete_LB_flow.add(
-                    vthunder_tasks.VThunderComputeConnectivityWait(
-                        name=a10constants.BACKUP_CONNECTIVITY_WAIT + "-before-unplug",
-                        rebind={a10constants.VTHUNDER: a10constants.BACKUP_VTHUNDER},
-                        requires=constants.AMPHORA))
-                delete_LB_flow.add(vthunder_tasks.AmphoraePostNetworkUnplug(
-                    name=a10constants.AMPHORA_POST_NETWORK_UNPLUG_FOR_BACKUP_VTHUNDER,
-                    requires=(constants.LOADBALANCER, constants.ADDED_PORTS),
-                    rebind={a10constants.VTHUNDER: a10constants.BACKUP_VTHUNDER}))
                 delete_LB_flow.add(
                     vthunder_tasks.VThunderComputeConnectivityWait(
                         name=a10constants.BACKUP_CONNECTIVITY_WAIT,
-                        rebind={a10constants.VTHUNDER: a10constants.BACKUP_VTHUNDER},
-                        requires=constants.AMPHORA))
+                        rebind={a10constants.VTHUNDER: a10constants.BACKUP_VTHUNDER,
+                                a10constants.MASTER_AMPHORA_STATUS:
+                                a10constants.BACKUP_AMPHORA_STATUS},
+                        requires=(constants.AMPHORA)))
                 delete_LB_flow.add(vthunder_tasks.VCSSyncWait(
                     name="vip-unplug-wait-vcs-ready",
-                    requires=a10constants.VTHUNDER))
+                    requires=(a10constants.VTHUNDER,
+                              a10constants.MASTER_AMPHORA_STATUS,
+                              a10constants.BACKUP_AMPHORA_STATUS)))
                 delete_LB_flow.add(vthunder_tasks.GetMasterVThunder(
                     name=a10constants.GET_VTHUNDER_MASTER,
                     requires=a10constants.VTHUNDER,
@@ -311,6 +326,13 @@ class LoadBalancerFlows(object):
             requires=(constants.LOADBALANCER, a10constants.VTHUNDER,
                       a10constants.LB_COUNT_FLAVOR, constants.FLAVOR_DATA)))
         if deleteCompute:
+            delete_LB_flow.add(glm_tasks.RevokeFlexpoolLicense(
+                name=a10constants.REVOKE_ACTIVE_VTHUNDER_LICENSE,
+                requires=a10constants.VTHUNDER))
+            if lb.topology == "ACTIVE_STANDBY":
+                delete_LB_flow.add(glm_tasks.RevokeFlexpoolLicense(
+                    name=a10constants.REVOKE_BACKUP_VTHUNDER_LICENSE,
+                    rebind={a10constants.VTHUNDER: a10constants.BACKUP_VTHUNDER}))
             delete_LB_flow.add(compute_tasks.DeleteAmphoraeOnLoadBalancer(
                 requires=constants.LOADBALANCER))
         delete_LB_flow.add(a10_database_tasks.MarkVThunderStatusInDB(
@@ -346,24 +368,37 @@ class LoadBalancerFlows(object):
         new_LB_net_subflow = linear_flow.Flow(constants.
                                               LOADBALANCER_NETWORKING_SUBFLOW)
         new_LB_net_subflow.add(database_tasks.GetAmphoraeFromLoadbalancer(
-            requires=constants.LOADBALANCER,
+            requires=constants.LOADBALANCER_ID,
             provides=constants.AMPHORA))
-        new_LB_net_subflow.add(vthunder_tasks.UpdateAcosVersionInVthunderEntry(
-            name=a10constants.UPDATE_ACOS_VERSION_IN_VTHUNDER_ENTRY,
-            requires=(constants.LOADBALANCER, a10constants.VTHUNDER)))
+        new_LB_net_subflow.add(a10_database_tasks.GetVThunderByLoadBalancer(
+            name=a10constants.GET_VTHUNDER_FROM_LB,
+            requires=constants.LOADBALANCER,
+            provides=a10constants.VTHUNDER))
         new_LB_net_subflow.add(a10_database_tasks.GetVThunderByLoadBalancer(
             name=a10constants.GET_VTHUNDER_BY_LB,
             requires=constants.LOADBALANCER,
             provides=a10constants.VTHUNDER))
-        if vthunder and topology == constants.TOPOLOGY_SINGLE:
+        if vthunder:
             new_LB_net_subflow.add(a10_database_tasks.GetLoadBalancerListByProjectID(
                 requires=a10constants.VTHUNDER,
                 provides=a10constants.LOADBALANCERS_LIST))
+            new_LB_net_subflow.add(a10_database_tasks.GetMemberListByProjectID(
+                requires=a10constants.VTHUNDER,
+                provides=a10constants.MEMBER_LIST))
             new_LB_net_subflow.add(a10_network_tasks.CalculateDelta(
-                requires=(constants.LOADBALANCER, a10constants.LOADBALANCERS_LIST),
+                requires=(constants.LOADBALANCER, a10constants.LOADBALANCERS_LIST,
+                          a10constants.MEMBER_LIST),
                 provides=constants.DELTAS))
             new_LB_net_subflow.add(a10_network_tasks.HandleNetworkDeltas(
                 requires=constants.DELTAS, provides=constants.ADDED_PORTS))
+            if topology == constants.TOPOLOGY_ACTIVE_STANDBY:
+                new_LB_net_subflow.add(vthunder_tasks.VCSSyncWait(
+                    name="wait-vcs-ready-before-master-reload",
+                    requires=a10constants.VTHUNDER))
+                new_LB_net_subflow.add(vthunder_tasks.GetMasterVThunder(
+                    name=a10constants.GET_MASTER_VTHUNDER,
+                    requires=a10constants.VTHUNDER,
+                    provides=a10constants.VTHUNDER))
             # managing interface additions here
             new_LB_net_subflow.add(vthunder_tasks.AmphoraePostVIPPlug(
                 name=a10constants.AMPHORAE_POST_VIP_PLUG,
@@ -373,6 +408,25 @@ class LoadBalancerFlows(object):
                 vthunder_tasks.VThunderComputeConnectivityWait(
                     name=a10constants.VTHUNDER_CONNECTIVITY_WAIT,
                     requires=(a10constants.VTHUNDER, constants.AMPHORA)))
+            if topology == constants.TOPOLOGY_ACTIVE_STANDBY:
+                new_LB_net_subflow.add(
+                    a10_database_tasks.GetBackupVThunderByLoadBalancer(
+                        name=a10constants.GET_BACKUP_VTHUNDER_BY_LB,
+                        requires=constants.LOADBALANCER,
+                        provides=a10constants.BACKUP_VTHUNDER))
+                new_LB_net_subflow.add(
+                    vthunder_tasks.VThunderComputeConnectivityWait(
+                        name=a10constants.BACKUP_CONNECTIVITY_WAIT,
+                        rebind={
+                            a10constants.VTHUNDER: a10constants.BACKUP_VTHUNDER},
+                        requires=constants.AMPHORA))
+                new_LB_net_subflow.add(vthunder_tasks.VCSSyncWait(
+                    name="wait-vcs-ready-after-reload",
+                    requires=a10constants.VTHUNDER))
+                new_LB_net_subflow.add(vthunder_tasks.GetMasterVThunder(
+                    name=a10constants.GET_VTHUNDER_MASTER,
+                    requires=a10constants.VTHUNDER,
+                    provides=a10constants.VTHUNDER))
             new_LB_net_subflow.add(vthunder_tasks.EnableInterface(
                 name=a10constants.ENABLE_VTHUNDER_INTERFACE,
                 requires=(a10constants.VTHUNDER, constants.LOADBALANCER,
@@ -392,115 +446,9 @@ class LoadBalancerFlows(object):
         if topology == constants.TOPOLOGY_ACTIVE_STANDBY:
             new_LB_net_subflow.add(
                 a10_database_tasks.GetBackupVThunderByLoadBalancer(
-                    name=a10constants.GET_BACKUP_VTHUNDER_BY_LB,
+                    name=a10constants.BACKUP_VTHUNDER,
                     requires=constants.LOADBALANCER,
                     provides=a10constants.BACKUP_VTHUNDER))
-            new_LB_net_subflow.add(vthunder_tasks.UpdateAcosVersionInVthunderEntry(
-                name=a10constants.UPDATE_ACOS_VERSION_FOR_BACKUP_VTHUNDER,
-                requires=constants.LOADBALANCER,
-                rebind={a10constants.VTHUNDER: a10constants.BACKUP_VTHUNDER}))
-            new_LB_net_subflow.add(
-                a10_database_tasks.GetBackupVThunderByLoadBalancer(
-                    name=a10constants.BACKUP_VTHUNDER,
-                    requires=(constants.LOADBALANCER, a10constants.VTHUNDER),
-                    provides=a10constants.BACKUP_VTHUNDER))
-            if vthunder:
-                new_LB_net_subflow.add(a10_database_tasks.GetLoadBalancerListByProjectID(
-                    requires=a10constants.VTHUNDER,
-                    provides=a10constants.LOADBALANCERS_LIST))
-                new_LB_net_subflow.add(a10_network_tasks.CalculateDelta(
-                    requires=(constants.LOADBALANCER, a10constants.LOADBALANCERS_LIST),
-                    provides=constants.DELTAS))
-                new_LB_net_subflow.add(a10_network_tasks.HandleNetworkDeltas(
-                    requires=constants.DELTAS, provides=constants.ADDED_PORTS))
-
-                # Make sure vcs ready before first probe-network-devices on Master
-                new_LB_net_subflow.add(
-                    vthunder_tasks.VThunderComputeConnectivityWait(
-                        name="backup-compute-conn-wait-before-probe-device",
-                        rebind={
-                            a10constants.VTHUNDER: a10constants.BACKUP_VTHUNDER},
-                        requires=constants.AMPHORA))
-                new_LB_net_subflow.add(vthunder_tasks.VCSSyncWait(
-                    name="wait-vcs-ready-before-probe-device",
-                    requires=a10constants.VTHUNDER))
-                new_LB_net_subflow.add(vthunder_tasks.AmphoraePostVIPPlug(
-                    name=a10constants.AMPHORAE_POST_VIP_PLUG_FOR_MASTER,
-                    requires=(constants.LOADBALANCER, a10constants.VTHUNDER,
-                              constants.ADDED_PORTS)))
-                new_LB_net_subflow.add(
-                    vthunder_tasks.VThunderComputeConnectivityWait(
-                        name="make-sure-backup-is-ready-after-reload-master",
-                        rebind={
-                            a10constants.VTHUNDER: a10constants.BACKUP_VTHUNDER},
-                        requires=constants.AMPHORA))
-                new_LB_net_subflow.add(vthunder_tasks.AmphoraePostVIPPlug(
-                    name=a10constants.AMPHORAE_POST_VIP_PLUG_FOR_BACKUP,
-                    requires=(constants.LOADBALANCER, constants.ADDED_PORTS),
-                    rebind={a10constants.VTHUNDER: a10constants.BACKUP_VTHUNDER}))
-                new_LB_net_subflow.add(
-                    vthunder_tasks.VThunderComputeConnectivityWait(
-                        name=a10constants.MASTER_CONNECTIVITY_WAIT,
-                        requires=(a10constants.VTHUNDER, constants.AMPHORA)))
-                new_LB_net_subflow.add(
-                    vthunder_tasks.VThunderComputeConnectivityWait(
-                        name=a10constants.BACKUP_CONNECTIVITY_WAIT,
-                        rebind={
-                            a10constants.VTHUNDER: a10constants.BACKUP_VTHUNDER},
-                        requires=constants.AMPHORA))
-                new_LB_net_subflow.add(vthunder_tasks.VCSSyncWait(
-                    name="backup-plug-wait-vcs-ready",
-                    requires=a10constants.VTHUNDER))
-                new_LB_net_subflow.add(vthunder_tasks.GetVThunderInterface(
-                    name=a10constants.GET_MASTER_VTHUNDER_INTERFACE,
-                    requires=a10constants.VTHUNDER,
-                    provides=(a10constants.IFNUM_MASTER, a10constants.IFNUM_BACKUP)))
-                new_LB_net_subflow.add(vthunder_tasks.EnableInterface(
-                    name=a10constants.MASTER_ENABLE_INTERFACE,
-                    requires=(a10constants.VTHUNDER, constants.LOADBALANCER, constants.ADDED_PORTS,
-                              a10constants.IFNUM_MASTER, a10constants.IFNUM_BACKUP)))
-                new_LB_net_subflow.add(vthunder_tasks.GetVThunderInterface(
-                    name=a10constants.GET_BACKUP_VTHUNDER_INTERFACE,
-                    requires=a10constants.VTHUNDER,
-                    rebind={a10constants.VTHUNDER: a10constants.BACKUP_VTHUNDER},
-                    provides=(a10constants.IFNUM_MASTER, a10constants.IFNUM_BACKUP)))
-                new_LB_net_subflow.add(vthunder_tasks.VCSSyncWait(
-                    name="wait-vcs-ready-before-master-reload",
-                    requires=a10constants.VTHUNDER))
-                new_LB_net_subflow.add(vthunder_tasks.AmphoraePostVIPPlug(
-                    name=a10constants.AMP_POST_VIP_PLUG,
-                    requires=(constants.LOADBALANCER, a10constants.VTHUNDER,
-                              constants.ADDED_PORTS)))
-                new_LB_net_subflow.add(
-                    vthunder_tasks.VThunderComputeConnectivityWait(
-                        name=a10constants.CONNECTIVITY_WAIT_FOR_MASTER_VTHUNDER,
-                        requires=(a10constants.VTHUNDER, constants.AMPHORA)))
-                new_LB_net_subflow.add(
-                    vthunder_tasks.VThunderComputeConnectivityWait(
-                        name=a10constants.CONNECTIVITY_WAIT_FOR_BACKUP_VTHUNDER,
-                        rebind={
-                            a10constants.VTHUNDER: a10constants.BACKUP_VTHUNDER},
-                        requires=constants.AMPHORA))
-                new_LB_net_subflow.add(vthunder_tasks.VCSSyncWait(
-                    name="int-sync-reload-wait-vcs-ready",
-                    requires=a10constants.VTHUNDER))
-                new_LB_net_subflow.add(vthunder_tasks.GetMasterVThunder(
-                    name=a10constants.GET_VTHUNDER_MASTER,
-                    requires=a10constants.VTHUNDER,
-                    provides=a10constants.VTHUNDER))
-                new_LB_net_subflow.add(a10_database_tasks.GetBackupVThunderByLoadBalancer(
-                    name="get-backup-vthunder-after-get-master",
-                    requires=(constants.LOADBALANCER, a10constants.VTHUNDER),
-                    provides=a10constants.BACKUP_VTHUNDER))
-                new_LB_net_subflow.add(vthunder_tasks.EnableInterface(
-                    name=a10constants.BACKUP_ENABLE_INTERFACE,
-                    requires=(a10constants.VTHUNDER, constants.LOADBALANCER, constants.ADDED_PORTS,
-                              a10constants.IFNUM_MASTER, a10constants.IFNUM_BACKUP)))
-            else:
-                new_LB_net_subflow.add(vthunder_tasks.VThunderComputeConnectivityWait(
-                    name=a10constants.CONNECTIVITY_WAIT_FOR_BACKUP_VTHUNDER,
-                    rebind={a10constants.VTHUNDER: a10constants.BACKUP_VTHUNDER},
-                    requires=constants.AMPHORA))
             new_LB_net_subflow.add(vthunder_tasks.EnableInterface(
                 name=a10constants.ENABLE_BACKUP_VTHUNDER_INTERFACE,
                 rebind={a10constants.VTHUNDER: a10constants.BACKUP_VTHUNDER},
@@ -553,7 +501,7 @@ class LoadBalancerFlows(object):
         if CONF.a10_global.handle_vrid:
             update_LB_flow.add(self.handle_vrid_for_loadbalancer_subflow())
         update_LB_flow.add(database_tasks.GetAmphoraeFromLoadbalancer(
-            requires=constants.LOADBALANCER,
+            requires=constants.LOADBALANCER_ID,
             provides=constants.AMPHORA))
         update_LB_flow.add(a10_database_tasks.GetLoadbalancersInProjectBySubnet(
             requires=[constants.SUBNET, a10constants.PARTITION_PROJECT_LIST],
@@ -572,7 +520,7 @@ class LoadBalancerFlows(object):
             provides=constants.FLAVOR_DATA))
         update_LB_flow.add(virtual_server_tasks.UpdateVirtualServerTask(
             requires=(constants.LOADBALANCER, a10constants.VTHUNDER,
-                      constants.FLAVOR_DATA)))
+                      constants.FLAVOR_DATA, constants.UPDATE_DICT)))
         update_LB_flow.add(database_tasks.UpdateLoadbalancerInDB(
             requires=[constants.LOADBALANCER, constants.UPDATE_DICT]))
         update_LB_flow.add(database_tasks.MarkLBActiveInDB(
@@ -626,7 +574,7 @@ class LoadBalancerFlows(object):
 
         update_LB_flow.add(virtual_server_tasks.UpdateVirtualServerTask(
             requires=(constants.LOADBALANCER, a10constants.VTHUNDER,
-                      constants.FLAVOR_DATA)))
+                      constants.FLAVOR_DATA, constants.UPDATE_DICT)))
         update_LB_flow.add(database_tasks.UpdateLoadbalancerInDB(
             requires=[constants.LOADBALANCER, constants.UPDATE_DICT]))
         if CONF.a10_global.network_type == 'vlan':
@@ -763,6 +711,11 @@ class LoadBalancerFlows(object):
         delete_LB_flow.add(nat_pool_tasks.NatPoolDelete(
             requires=(constants.LOADBALANCER, a10constants.VTHUNDER,
                       a10constants.LB_COUNT_FLAVOR, constants.FLAVOR_DATA)))
+        delete_LB_flow.add(a10_database_tasks.CountLBThunderPartition(
+            requires=a10constants.VTHUNDER,
+            provides=a10constants.LB_COUNT_THUNDER_PARTITION))
+        delete_LB_flow.add(vthunder_tasks.DeleteHealthMonitorOnVThunder(
+            requires=(a10constants.LB_COUNT_THUNDER_PARTITION, a10constants.VTHUNDER)))
         if CONF.a10_global.network_type == 'vlan':
             delete_LB_flow.add(
                 vthunder_tasks.DeleteInterfaceTagIfNotInUseForLB(
@@ -815,6 +768,10 @@ class LoadBalancerFlows(object):
                 provides=constants.LOADBALANCER))
         post_create_lb_flow.add(database_tasks.UpdateLoadbalancerInDB(
             requires=[constants.LOADBALANCER, constants.UPDATE_DICT]))
+        post_create_lb_flow.add(
+            vthunder_tasks.CreateHealthMonitorOnVThunder(
+                name=a10constants.CREATE_HEALTH_MONITOR_ON_VTHUNDER,
+                requires=a10constants.VTHUNDER))
         if CONF.a10_global.network_type == 'vlan':
             post_create_lb_flow.add(vthunder_tasks.TagInterfaceForLB(
                 requires=[constants.LOADBALANCER,
@@ -843,7 +800,8 @@ class LoadBalancerFlows(object):
             a10_database_tasks.GetVRIDForLoadbalancerResource(
                 requires=[
                     a10constants.PARTITION_PROJECT_LIST,
-                    a10constants.VTHUNDER],
+                    a10constants.VTHUNDER,
+                    constants.LOADBALANCER],
                 provides=a10constants.VRID_LIST))
         handle_vrid_for_lb_subflow.add(vthunder_tasks.ConfigureVRID(
             requires=a10constants.VTHUNDER))
@@ -889,7 +847,8 @@ class LoadBalancerFlows(object):
             a10_database_tasks.GetVRIDForLoadbalancerResource(
                 requires=[
                     a10constants.PARTITION_PROJECT_LIST,
-                    a10constants.VTHUNDER],
+                    a10constants.VTHUNDER,
+                    constants.LOADBALANCER],
                 provides=a10constants.VRID_LIST))
         delete_lb_vrid_subflow.add(
             a10_network_tasks.DeleteVRIDPort(
@@ -924,7 +883,8 @@ class LoadBalancerFlows(object):
             a10_database_tasks.GetVRIDForLoadbalancerResource(
                 requires=[
                     a10constants.PARTITION_PROJECT_LIST,
-                    a10constants.VTHUNDER],
+                    a10constants.VTHUNDER,
+                    constants.LOADBALANCER],
                 provides=a10constants.VRID_LIST))
         delete_lb_vrid_subflow.add(
             a10_network_tasks.DeleteVRIDPort(
