@@ -17,9 +17,9 @@ from oslo_config import cfg
 from taskflow.patterns import linear_flow
 
 from octavia.common import constants
-from octavia.controller.worker.tasks import database_tasks
-from octavia.controller.worker.tasks import lifecycle_tasks
-from octavia.controller.worker.tasks import model_tasks
+from octavia.controller.worker.v1.tasks import database_tasks
+from octavia.controller.worker.v1.tasks import lifecycle_tasks
+from octavia.controller.worker.v1.tasks import model_tasks
 
 from a10_octavia.common import a10constants
 from a10_octavia.controller.worker.tasks import a10_database_tasks
@@ -48,10 +48,9 @@ class MemberFlows(object):
 
         create_member_flow.add(database_tasks.MarkMemberPendingCreateInDB(
             requires=constants.MEMBER))
-        if CONF.a10_global.validate_subnet:
-            create_member_flow.add(a10_network_tasks.ValidateSubnet(
-                name='validate-subnet',
-                requires=constants.MEMBER))
+        create_member_flow.add(a10_network_tasks.ValidateSubnet(
+            name='validate-subnet',
+            requires=constants.MEMBER))
         create_member_flow.add(a10_database_tasks.GetVThunderByLoadBalancer(
             requires=constants.LOADBALANCER,
             provides=a10constants.VTHUNDER))
@@ -59,31 +58,35 @@ class MemberFlows(object):
             requires=a10constants.VTHUNDER,
             provides=a10constants.LOADBALANCERS_LIST))
         create_member_flow.add(database_tasks.GetAmphoraeFromLoadbalancer(
-            requires=constants.LOADBALANCER,
+            requires=constants.LOADBALANCER_ID,
             provides=constants.AMPHORA))
+        create_member_flow.add(a10_database_tasks.GetMemberListByProjectID(
+            requires=a10constants.VTHUNDER,
+            provides=a10constants.MEMBER_LIST))
         create_member_flow.add(a10_network_tasks.CalculateDelta(
-            requires=(constants.LOADBALANCER, a10constants.LOADBALANCERS_LIST),
+            requires=(constants.LOADBALANCER, a10constants.LOADBALANCERS_LIST,
+                      a10constants.MEMBER_LIST),
             provides=constants.DELTAS))
         create_member_flow.add(a10_network_tasks.HandleNetworkDeltas(
             requires=constants.DELTAS, provides=constants.ADDED_PORTS))
+        if topology == constants.TOPOLOGY_ACTIVE_STANDBY:
+            create_member_flow.add(vthunder_tasks.VCSSyncWait(
+                name="vcs_sync_wait_before_probe_device",
+                requires=a10constants.VTHUNDER))
+            create_member_flow.add(vthunder_tasks.GetMasterVThunder(
+                name=a10constants.GET_VTHUNDER_MASTER,
+                requires=a10constants.VTHUNDER,
+                provides=a10constants.VTHUNDER))
         # managing interface additions here
-        if topology == constants.TOPOLOGY_SINGLE:
-            create_member_flow.add(
-                vthunder_tasks.AmphoraePostMemberNetworkPlug(
-                    requires=(
-                        constants.LOADBALANCER,
-                        constants.ADDED_PORTS,
-                        a10constants.VTHUNDER)))
-            create_member_flow.add(vthunder_tasks.VThunderComputeConnectivityWait(
-                name=a10constants.VTHUNDER_CONNECTIVITY_WAIT,
-                requires=(a10constants.VTHUNDER, constants.AMPHORA)))
-            create_member_flow.add(
-                vthunder_tasks.EnableInterfaceForMembers(
-                    requires=[
-                        constants.ADDED_PORTS,
-                        constants.LOADBALANCER,
-                        a10constants.VTHUNDER]))
-        # configure member flow for HA
+        create_member_flow.add(
+            vthunder_tasks.AmphoraePostMemberNetworkPlug(
+                requires=(
+                    constants.LOADBALANCER,
+                    constants.ADDED_PORTS,
+                    a10constants.VTHUNDER)))
+        create_member_flow.add(vthunder_tasks.VThunderComputeConnectivityWait(
+            name=a10constants.VTHUNDER_CONNECTIVITY_WAIT,
+            requires=(a10constants.VTHUNDER, constants.AMPHORA)))
         if topology == constants.TOPOLOGY_ACTIVE_STANDBY:
             create_member_flow.add(
                 a10_database_tasks.GetBackupVThunderByLoadBalancer(
@@ -94,27 +97,6 @@ class MemberFlows(object):
                 name="backup_compute_conn_wait_before_probe_device",
                 requires=constants.AMPHORA,
                 rebind={a10constants.VTHUNDER: a10constants.BACKUP_VTHUNDER}))
-            create_member_flow.add(vthunder_tasks.VCSSyncWait(
-                name="vcs_sync_wait_before_probe_device",
-                requires=a10constants.VTHUNDER))
-            create_member_flow.add(
-                vthunder_tasks.AmphoraePostMemberNetworkPlug(
-                    requires=(
-                        constants.LOADBALANCER,
-                        constants.ADDED_PORTS,
-                        a10constants.VTHUNDER)))
-            create_member_flow.add(
-                vthunder_tasks.AmphoraePostMemberNetworkPlug(
-                    name="backup_amphora_network_plug", requires=[
-                        constants.ADDED_PORTS, constants.LOADBALANCER], rebind={
-                        a10constants.VTHUNDER: a10constants.BACKUP_VTHUNDER}))
-            create_member_flow.add(vthunder_tasks.VThunderComputeConnectivityWait(
-                name=a10constants.MASTER_CONNECTIVITY_WAIT,
-                requires=(a10constants.VTHUNDER, constants.AMPHORA)))
-            create_member_flow.add(vthunder_tasks.VThunderComputeConnectivityWait(
-                name=a10constants.BACKUP_CONNECTIVITY_WAIT,
-                requires=constants.AMPHORA,
-                rebind={a10constants.VTHUNDER: a10constants.BACKUP_VTHUNDER}))
             create_member_flow.add(vthunder_tasks.VCSSyncWait(
                 name="backup-plug-wait-vcs-ready",
                 requires=a10constants.VTHUNDER))
@@ -122,44 +104,12 @@ class MemberFlows(object):
                 name=a10constants.GET_MASTER_VTHUNDER,
                 requires=a10constants.VTHUNDER,
                 provides=a10constants.VTHUNDER))
-            create_member_flow.add(a10_database_tasks.GetBackupVThunderByLoadBalancer(
-                name="get_backup_vThunder_after_get_master",
-                requires=(constants.LOADBALANCER, a10constants.VTHUNDER),
-                provides=a10constants.BACKUP_VTHUNDER))
-            create_member_flow.add(
-                vthunder_tasks.EnableInterfaceForMembers(
-                    name=a10constants.ENABLE_MASTER_VTHUNDER_INTERFACE,
-                    requires=[
-                        constants.ADDED_PORTS,
-                        constants.LOADBALANCER,
-                        a10constants.VTHUNDER]))
-            create_member_flow.add(vthunder_tasks.AmphoraePostMemberNetworkPlug(
-                name="amphorae-post-member-network-plug-for-master",
-                requires=(constants.LOADBALANCER, constants.ADDED_PORTS,
-                          a10constants.VTHUNDER)))
-            create_member_flow.add(
-                vthunder_tasks.VThunderComputeConnectivityWait(
-                    name=a10constants.CONNECTIVITY_WAIT_FOR_MASTER_VTHUNDER,
-                    requires=(a10constants.VTHUNDER, constants.AMPHORA)))
-            create_member_flow.add(
-                vthunder_tasks.VThunderComputeConnectivityWait(
-                    name=a10constants.CONNECTIVITY_WAIT_FOR_BACKUP_VTHUNDER,
-                    rebind={
-                        a10constants.VTHUNDER: a10constants.BACKUP_VTHUNDER},
-                    requires=constants.AMPHORA))
-            create_member_flow.add(vthunder_tasks.VCSSyncWait(
-                name="member_enable_interface_vcs_sync_wait",
-                requires=a10constants.VTHUNDER))
-            create_member_flow.add(vthunder_tasks.GetMasterVThunder(
-                name=a10constants.GET_VTHUNDER_MASTER,
-                requires=a10constants.VTHUNDER,
-                provides=a10constants.VTHUNDER))
-            create_member_flow.add(
-                vthunder_tasks.EnableInterfaceForMembers(
-                    requires=[
-                        constants.ADDED_PORTS,
-                        constants.LOADBALANCER,
-                        a10constants.VTHUNDER]))
+        create_member_flow.add(
+            vthunder_tasks.EnableInterfaceForMembers(
+                requires=[
+                    constants.ADDED_PORTS,
+                    constants.LOADBALANCER,
+                    a10constants.VTHUNDER]))
         if CONF.a10_global.handle_vrid:
             create_member_flow.add(self.handle_vrid_for_member_subflow())
         create_member_flow.add(a10_database_tasks.CountMembersWithIP(
@@ -209,7 +159,7 @@ class MemberFlows(object):
                                DeleteModelObject(rebind={constants.OBJECT:
                                                          constants.MEMBER}))
         delete_member_flow.add(database_tasks.GetAmphoraeFromLoadbalancer(
-            requires=constants.LOADBALANCER,
+            requires=constants.LOADBALANCER_ID,
             provides=constants.AMPHORA))
         delete_member_flow.add(a10_database_tasks.GetVThunderByLoadBalancer(
             requires=constants.LOADBALANCER,
@@ -228,11 +178,23 @@ class MemberFlows(object):
         delete_member_flow.add(a10_database_tasks.GetLoadBalancerListByProjectID(
             requires=a10constants.VTHUNDER,
             provides=a10constants.LOADBALANCERS_LIST))
+        delete_member_flow.add(a10_database_tasks.GetMemberListByProjectID(
+            requires=a10constants.VTHUNDER,
+            provides=a10constants.MEMBER_LIST))
         delete_member_flow.add(a10_network_tasks.CalculateDelta(
-            requires=(constants.LOADBALANCER, a10constants.LOADBALANCERS_LIST),
+            requires=(constants.LOADBALANCER, a10constants.LOADBALANCERS_LIST,
+                      a10constants.MEMBER_LIST),
             provides=constants.DELTAS))
         delete_member_flow.add(a10_network_tasks.HandleNetworkDeltas(
             requires=constants.DELTAS, provides=constants.ADDED_PORTS))
+        if topology == constants.TOPOLOGY_ACTIVE_STANDBY:
+            delete_member_flow.add(vthunder_tasks.VCSSyncWait(
+                name=a10constants.VCS_SYNC_WAIT,
+                requires=a10constants.VTHUNDER))
+            delete_member_flow.add(vthunder_tasks.GetMasterVThunder(
+                name=a10constants.GET_MASTER_VTHUNDER,
+                requires=a10constants.VTHUNDER,
+                provides=a10constants.VTHUNDER))
         delete_member_flow.add(
             vthunder_tasks.AmphoraePostNetworkUnplug(
                 requires=(
@@ -253,16 +215,6 @@ class MemberFlows(object):
                     name=a10constants.BACKUP_CONNECTIVITY_WAIT + "-before-unplug",
                     requires=constants.AMPHORA,
                     rebind={a10constants.VTHUNDER: a10constants.BACKUP_VTHUNDER}))
-            delete_member_flow.add(
-                vthunder_tasks.AmphoraePostNetworkUnplug(
-                    name=a10constants.AMPHORA_POST_NETWORK_UNPLUG_FOR_BACKUP_VTHUNDER,
-                    requires=(constants.LOADBALANCER, constants.ADDED_PORTS),
-                    rebind={a10constants.VTHUNDER: a10constants.BACKUP_VTHUNDER}))
-            delete_member_flow.add(
-                vthunder_tasks.VThunderComputeConnectivityWait(
-                    name=a10constants.BACKUP_CONNECTIVITY_WAIT,
-                    requires=constants.AMPHORA,
-                    rebind={a10constants.VTHUNDER: a10constants.BACKUP_VTHUNDER}))
             delete_member_flow.add(vthunder_tasks.VCSSyncWait(
                 name='member-unplug-' + a10constants.VCS_SYNC_WAIT,
                 requires=a10constants.VTHUNDER))
@@ -497,7 +449,8 @@ class MemberFlows(object):
             a10_database_tasks.GetVRIDForLoadbalancerResource(
                 requires=[
                     a10constants.PARTITION_PROJECT_LIST,
-                    a10constants.VTHUNDER],
+                    a10constants.VTHUNDER,
+                    constants.LOADBALANCER],
                 provides=a10constants.VRID_LIST))
         delete_member_vrid_subflow.add(
             a10_network_tasks.DeleteVRIDPort(
@@ -541,7 +494,8 @@ class MemberFlows(object):
                 name='get_vrid_for_loadbalancer_resource' + pool,
                 requires=[
                     a10constants.PARTITION_PROJECT_LIST,
-                    a10constants.VTHUNDER],
+                    a10constants.VTHUNDER,
+                    constants.LOADBALANCER],
                 provides=a10constants.VRID_LIST))
         delete_member_vrid_subflow.add(
             a10_network_tasks.DeleteMultipleVRIDPort(
@@ -574,7 +528,8 @@ class MemberFlows(object):
             a10_database_tasks.GetVRIDForLoadbalancerResource(
                 requires=[
                     a10constants.PARTITION_PROJECT_LIST,
-                    a10constants.VTHUNDER],
+                    a10constants.VTHUNDER,
+                    constants.LOADBALANCER],
                 provides=a10constants.VRID_LIST))
         handle_vrid_for_member_subflow.add(
             a10_network_tasks.HandleVRIDFloatingIP(
@@ -613,10 +568,9 @@ class MemberFlows(object):
 
         update_member_flow.add(database_tasks.MarkMemberPendingUpdateInDB(
             requires=constants.MEMBER))
-        if CONF.a10_global.validate_subnet:
-            update_member_flow.add(a10_network_tasks.ValidateSubnet(
-                name='validate-subnet',
-                requires=constants.MEMBER))
+        update_member_flow.add(a10_network_tasks.ValidateSubnet(
+            name='validate-subnet',
+            requires=constants.MEMBER))
         update_member_flow.add(a10_database_tasks.GetVThunderByLoadBalancer(
             requires=constants.LOADBALANCER,
             provides=a10constants.VTHUNDER))
@@ -628,7 +582,7 @@ class MemberFlows(object):
         if CONF.a10_global.handle_vrid:
             update_member_flow.add(self.handle_vrid_for_member_subflow())
         update_member_flow.add(database_tasks.GetAmphoraeFromLoadbalancer(
-            requires=constants.LOADBALANCER,
+            requires=constants.LOADBALANCER_ID,
             provides=constants.AMPHORA))
         update_member_flow.add(a10_database_tasks.GetLoadbalancersInProjectBySubnet(
             requires=[constants.SUBNET, a10constants.PARTITION_PROJECT_LIST],
@@ -648,7 +602,8 @@ class MemberFlows(object):
             provides=constants.FLAVOR))
         update_member_flow.add(server_tasks.MemberUpdate(
             requires=(constants.MEMBER, a10constants.VTHUNDER,
-                      constants.POOL, constants.FLAVOR)))
+                      constants.POOL, constants.FLAVOR,
+                      constants.UPDATE_DICT)))
         update_member_flow.add(database_tasks.UpdateMemberInDB(
             requires=[constants.MEMBER, constants.UPDATE_DICT]))
         update_member_flow.add(database_tasks.MarkMemberActiveInDB(
@@ -678,10 +633,9 @@ class MemberFlows(object):
                       constants.POOL]))
         update_member_flow.add(database_tasks.MarkMemberPendingUpdateInDB(
             requires=constants.MEMBER))
-        if CONF.a10_global.validate_subnet:
-            update_member_flow.add(a10_network_tasks.ValidateSubnet(
-                name='validate-subnet',
-                requires=constants.MEMBER))
+        update_member_flow.add(a10_network_tasks.ValidateSubnet(
+            name='validate-subnet',
+            requires=constants.MEMBER))
         update_member_flow.add(a10_database_tasks.GetVThunderByLoadBalancer(
             requires=constants.LOADBALANCER,
             provides=a10constants.VTHUNDER))
@@ -706,7 +660,8 @@ class MemberFlows(object):
             update_member_flow.add(self.handle_vrid_for_member_subflow())
         update_member_flow.add(server_tasks.MemberUpdate(
             requires=(constants.MEMBER, a10constants.VTHUNDER,
-                      constants.POOL, constants.FLAVOR)))
+                      constants.POOL, constants.FLAVOR,
+                      constants.UPDATE_DICT)))
         update_member_flow.add(database_tasks.UpdateMemberInDB(
             requires=[constants.MEMBER, constants.UPDATE_DICT]))
         if CONF.a10_global.network_type == 'vlan':
@@ -739,10 +694,9 @@ class MemberFlows(object):
                       constants.POOL]))
         create_member_flow.add(database_tasks.MarkMemberPendingCreateInDB(
             requires=constants.MEMBER))
-        if CONF.a10_global.validate_subnet:
-            create_member_flow.add(a10_network_tasks.ValidateSubnet(
-                name='validate-subnet',
-                requires=constants.MEMBER))
+        create_member_flow.add(a10_network_tasks.ValidateSubnet(
+            name='validate-subnet',
+            requires=constants.MEMBER))
         create_member_flow.add(a10_database_tasks.GetVThunderByLoadBalancer(
             requires=constants.LOADBALANCER,
             provides=a10constants.VTHUNDER))
@@ -907,10 +861,9 @@ class MemberFlows(object):
             batch_update_members_flow.add(database_tasks.MarkMemberPendingCreateInDB(
                 name='mark-member-pending-create-in-db-' + m.id,
                 inject={constants.MEMBER: m}))
-            if CONF.a10_global.validate_subnet:
-                batch_update_members_flow.add(a10_network_tasks.ValidateSubnet(
-                    name='validate-subnet' + m.id,
-                    inject={constants.MEMBER: m}))
+            batch_update_members_flow.add(a10_network_tasks.ValidateSubnet(
+                name='validate-subnet' + m.id,
+                inject={constants.MEMBER: m}))
             batch_update_members_flow.add(a10_database_tasks.CountMembersWithIP(
                 name='count-member-with-ip-' + m.id,
                 inject={constants.MEMBER: m},
@@ -938,10 +891,9 @@ class MemberFlows(object):
             batch_update_members_flow.add(database_tasks.MarkMemberPendingUpdateInDB(
                 inject={constants.MEMBER: m},
                 name='mark-member-pending-update-in-db-' + m.id))
-            if CONF.a10_global.validate_subnet:
-                batch_update_members_flow.add(a10_network_tasks.ValidateSubnet(
-                    name='validate-subnet' + m.id,
-                    inject={constants.MEMBER: m}))
+            batch_update_members_flow.add(a10_network_tasks.ValidateSubnet(
+                name='validate-subnet' + m.id,
+                inject={constants.MEMBER: m}))
             batch_update_members_flow.add(server_tasks.MemberUpdate(
                 name='member-update-' + m.id,
                 inject={constants.MEMBER: m},
@@ -980,26 +932,6 @@ class MemberFlows(object):
 
         return batch_update_members_flow
 
-    def get_batch_update_member_snat_pool_subflow(self, member):
-        batch_update_member_snat_subflow = linear_flow.Flow(
-            a10constants.CREATE_MEMBER_SNAT_POOL_SUBFLOW)
-        batch_update_member_snat_subflow.add(a10_database_tasks.GetNatPoolEntry(
-            name='get-nat-pool-entry-' + member.id,
-            inject={constants.MEMBER: member},
-            requires=a10constants.NAT_FLAVOR,
-            provides=a10constants.NAT_POOL))
-        batch_update_member_snat_subflow.add(a10_network_tasks.ReserveSubnetAddressForMember(
-            name='reserve-subnet-address-for-member' + member.id,
-            inject={constants.MEMBER: member},
-            requires=[a10constants.NAT_FLAVOR, a10constants.NAT_POOL],
-            provides=a10constants.SUBNET_PORT))
-        batch_update_member_snat_subflow.add(a10_database_tasks.UpdateNatPoolDB(
-            name='update-nat-pool-DB-' + member.id,
-            inject={constants.MEMBER: member},
-            requires=[a10constants.NAT_FLAVOR,
-                      a10constants.NAT_POOL, a10constants.SUBNET_PORT]))
-        return batch_update_member_snat_subflow
-
     def get_batch_update_members_flow(self, old_members, new_members, updated_members, topology):
         """Create a flow to batch update members
         :returns: The flow for batch updating members
@@ -1009,7 +941,7 @@ class MemberFlows(object):
         batch_update_members_flow.add(vthunder_tasks.VthunderInstanceBusy(
             requires=a10constants.COMPUTE_BUSY))
         batch_update_members_flow.add(database_tasks.GetAmphoraeFromLoadbalancer(
-            requires=constants.LOADBALANCER,
+            requires=constants.LOADBALANCER_ID,
             provides=constants.AMPHORA))
         batch_update_members_flow.add(a10_database_tasks.GetVThunderByLoadBalancer(
             requires=constants.LOADBALANCER,
@@ -1091,10 +1023,9 @@ class MemberFlows(object):
             batch_update_members_flow.add(database_tasks.MarkMemberPendingCreateInDB(
                 name='mark-member-pending-create-in-DB' + m.id,
                 inject={constants.MEMBER: m}))
-            if CONF.a10_global.validate_subnet:
-                batch_update_members_flow.add(a10_network_tasks.ValidateSubnet(
-                    name='validate-subnet' + m.id,
-                    inject={constants.MEMBER: m}))
+            batch_update_members_flow.add(a10_network_tasks.ValidateSubnet(
+                name='validate-subnet' + m.id,
+                inject={constants.MEMBER: m}))
             batch_update_members_flow.add(a10_database_tasks.CountMembersWithIP(
                 name='count-members-with-ip' + m.id,
                 inject={constants.MEMBER: m},
@@ -1124,10 +1055,9 @@ class MemberFlows(object):
             batch_update_members_flow.add(database_tasks.MarkMemberPendingUpdateInDB(
                 inject={constants.MEMBER: m},
                 name='mark-member-pending-update-in-db-' + m.id))
-            if CONF.a10_global.validate_subnet:
-                batch_update_members_flow.add(a10_network_tasks.ValidateSubnet(
-                    name='validate-subnet' + m.id,
-                    inject={constants.MEMBER: m}))
+            batch_update_members_flow.add(a10_network_tasks.ValidateSubnet(
+                name='validate-subnet' + m.id,
+                inject={constants.MEMBER: m}))
             batch_update_members_flow.add(a10_network_tasks.GetLBResourceSubnet(
                 name='{flow}-{id}'.format(
                     id=m.id, flow=a10constants.GET_LB_RESOURCE_SUBNET),
@@ -1163,47 +1093,41 @@ class MemberFlows(object):
         batch_update_members_flow.add(a10_database_tasks.GetLoadBalancerListByProjectID(
             requires=a10constants.VTHUNDER,
             provides=a10constants.LOADBALANCERS_LIST))
+        batch_update_members_flow.add(a10_database_tasks.GetMemberListByProjectID(
+            requires=a10constants.VTHUNDER,
+            provides=a10constants.MEMBER_LIST))
         batch_update_members_flow.add(a10_network_tasks.CalculateDelta(
-            requires=(constants.LOADBALANCER, a10constants.LOADBALANCERS_LIST),
+            requires=(constants.LOADBALANCER, a10constants.LOADBALANCERS_LIST,
+                      a10constants.MEMBER_LIST),
             provides=constants.DELTAS))
         batch_update_members_flow.add(a10_network_tasks.HandleNetworkDeltas(
             requires=constants.DELTAS, provides=constants.ADDED_PORTS))
-        # managing interface additions here
-        if topology == constants.TOPOLOGY_SINGLE:
-            batch_update_members_flow.add(vthunder_tasks.AmphoraePostMemberNetworkPlug(
-                requires=(constants.LOADBALANCER, constants.ADDED_PORTS,
-                          a10constants.VTHUNDER)))
-            batch_update_members_flow.add(vthunder_tasks.VThunderComputeConnectivityWait(
-                name=a10constants.VTHUNDER_CONNECTIVITY_WAIT,
-                requires=(a10constants.VTHUNDER, constants.AMPHORA)))
-            batch_update_members_flow.add(vthunder_tasks.EnableInterfaceForMembers(
-                requires=[constants.ADDED_PORTS, constants.LOADBALANCER,
-                          a10constants.VTHUNDER]))
-        # configure member flow for HA
         if topology == constants.TOPOLOGY_ACTIVE_STANDBY:
-            batch_update_members_flow.add(a10_database_tasks.GetBackupVThunderByLoadBalancer(
-                name="get_backup_vThunder",
-                requires=(constants.LOADBALANCER, a10constants.VTHUNDER),
-                provides=a10constants.BACKUP_VTHUNDER))
-            batch_update_members_flow.add(vthunder_tasks.VThunderComputeConnectivityWait(
-                name="backup_compute_conn_wait_before_probe_device",
-                requires=constants.AMPHORA,
-                rebind={a10constants.VTHUNDER: a10constants.BACKUP_VTHUNDER}))
             batch_update_members_flow.add(vthunder_tasks.VCSSyncWait(
                 name="vcs_sync_wait_before_probe_device",
                 requires=a10constants.VTHUNDER))
-            batch_update_members_flow.add(vthunder_tasks.AmphoraePostMemberNetworkPlug(
-                requires=(constants.LOADBALANCER, constants.ADDED_PORTS,
-                          a10constants.VTHUNDER)))
-            batch_update_members_flow.add(vthunder_tasks.AmphoraePostMemberNetworkPlug(
-                name="backup_amphora_network_plug",
-                requires=[constants.ADDED_PORTS, constants.LOADBALANCER],
-                rebind={a10constants.VTHUNDER: a10constants.BACKUP_VTHUNDER}))
+            batch_update_members_flow.add(vthunder_tasks.GetMasterVThunder(
+                name=a10constants.GET_VTHUNDER_MASTER,
+                requires=a10constants.VTHUNDER,
+                provides=a10constants.VTHUNDER))
+        # managing interface additions here
+        batch_update_members_flow.add(
+            vthunder_tasks.AmphoraePostMemberNetworkPlug(
+                requires=(
+                    constants.LOADBALANCER,
+                    constants.ADDED_PORTS,
+                    a10constants.VTHUNDER)))
+        batch_update_members_flow.add(vthunder_tasks.VThunderComputeConnectivityWait(
+            name=a10constants.VTHUNDER_CONNECTIVITY_WAIT,
+            requires=(a10constants.VTHUNDER, constants.AMPHORA)))
+        if topology == constants.TOPOLOGY_ACTIVE_STANDBY:
+            batch_update_members_flow.add(
+                a10_database_tasks.GetBackupVThunderByLoadBalancer(
+                    name="get_backup_vThunder",
+                    requires=(constants.LOADBALANCER, a10constants.VTHUNDER),
+                    provides=a10constants.BACKUP_VTHUNDER))
             batch_update_members_flow.add(vthunder_tasks.VThunderComputeConnectivityWait(
-                name=a10constants.MASTER_CONNECTIVITY_WAIT,
-                requires=(a10constants.VTHUNDER, constants.AMPHORA)))
-            batch_update_members_flow.add(vthunder_tasks.VThunderComputeConnectivityWait(
-                name=a10constants.BACKUP_CONNECTIVITY_WAIT,
+                name="backup_compute_conn_wait_before_probe_device",
                 requires=constants.AMPHORA,
                 rebind={a10constants.VTHUNDER: a10constants.BACKUP_VTHUNDER}))
             batch_update_members_flow.add(vthunder_tasks.VCSSyncWait(
@@ -1213,41 +1137,16 @@ class MemberFlows(object):
                 name=a10constants.GET_MASTER_VTHUNDER,
                 requires=a10constants.VTHUNDER,
                 provides=a10constants.VTHUNDER))
-            batch_update_members_flow.add(a10_database_tasks.GetBackupVThunderByLoadBalancer(
-                name="get_backup_vThunder_after_get_master",
-                requires=(constants.LOADBALANCER, a10constants.VTHUNDER),
-                provides=a10constants.BACKUP_VTHUNDER))
-            batch_update_members_flow.add(vthunder_tasks.EnableInterfaceForMembers(
-                name=a10constants.ENABLE_MASTER_VTHUNDER_INTERFACE,
-                requires=[constants.ADDED_PORTS, constants.LOADBALANCER,
-                          a10constants.VTHUNDER]))
-            batch_update_members_flow.add(vthunder_tasks.AmphoraePostMemberNetworkPlug(
-                name="amphorae-post-member-network-plug-for-master",
-                requires=(constants.LOADBALANCER, constants.ADDED_PORTS,
-                          a10constants.VTHUNDER)))
-            batch_update_members_flow.add(
-                vthunder_tasks.VThunderComputeConnectivityWait(
-                    name=a10constants.CONNECTIVITY_WAIT_FOR_MASTER_VTHUNDER,
-                    requires=(a10constants.VTHUNDER, constants.AMPHORA)))
-            batch_update_members_flow.add(
-                vthunder_tasks.VThunderComputeConnectivityWait(
-                    name=a10constants.CONNECTIVITY_WAIT_FOR_BACKUP_VTHUNDER,
-                    rebind={a10constants.VTHUNDER: a10constants.BACKUP_VTHUNDER},
-                    requires=constants.AMPHORA))
-            batch_update_members_flow.add(vthunder_tasks.VCSSyncWait(
-                name="member_enable_interface_vcs_sync_wait",
-                requires=a10constants.VTHUNDER))
-            batch_update_members_flow.add(vthunder_tasks.GetMasterVThunder(
-                name=a10constants.GET_VTHUNDER_MASTER,
-                requires=a10constants.VTHUNDER,
-                provides=a10constants.VTHUNDER))
-            batch_update_members_flow.add(vthunder_tasks.EnableInterfaceForMembers(
-                requires=[constants.ADDED_PORTS, constants.LOADBALANCER,
-                          a10constants.VTHUNDER]))
+        batch_update_members_flow.add(
+            vthunder_tasks.EnableInterfaceForMembers(
+                requires=[
+                    constants.ADDED_PORTS,
+                    constants.LOADBALANCER,
+                    a10constants.VTHUNDER]))
         existing_members = [m[0] for m in updated_members]
         pool_members = new_members + existing_members
-        if pool_members:
-            if CONF.a10_global.handle_vrid:
+        if CONF.a10_global.handle_vrid:
+            if pool_members:
                 batch_update_members_flow.add(
                     self.get_handle_member_vrid_internal_subflow(pool_members))
         for m in new_members:
@@ -1263,6 +1162,26 @@ class MemberFlows(object):
             requires=a10constants.VTHUNDER))
         return batch_update_members_flow
 
+    def get_batch_update_member_snat_pool_subflow(self, member):
+        batch_update_member_snat_subflow = linear_flow.Flow(
+            a10constants.CREATE_MEMBER_SNAT_POOL_SUBFLOW)
+        batch_update_member_snat_subflow.add(a10_database_tasks.GetNatPoolEntry(
+            name='get-nat-pool-entry-' + member.id,
+            inject={constants.MEMBER: member},
+            requires=a10constants.NAT_FLAVOR,
+            provides=a10constants.NAT_POOL))
+        batch_update_member_snat_subflow.add(a10_network_tasks.ReserveSubnetAddressForMember(
+            name='reserve-subnet-address-for-member' + member.id,
+            inject={constants.MEMBER: member},
+            requires=[a10constants.NAT_FLAVOR, a10constants.NAT_POOL],
+            provides=a10constants.SUBNET_PORT))
+        batch_update_member_snat_subflow.add(a10_database_tasks.UpdateNatPoolDB(
+            name='update-nat-pool-DB-' + member.id,
+            inject={constants.MEMBER: member},
+            requires=[a10constants.NAT_FLAVOR,
+                      a10constants.NAT_POOL, a10constants.SUBNET_PORT]))
+        return batch_update_member_snat_subflow
+
     def get_handle_member_vrid_internal_subflow(self, pool_members):
         handle_vrid_for_member_subflow = linear_flow.Flow(
             a10constants.DELETE_MEMBER_VRID_INTERNAL_SUBFLOW)
