@@ -19,12 +19,14 @@ from taskflow.patterns import graph_flow
 from taskflow.patterns import linear_flow
 
 from octavia.common import constants
-from octavia.controller.worker.tasks import database_tasks
+from octavia.controller.worker.v1.tasks import compute_tasks as compute
+from octavia.controller.worker.v1.tasks import database_tasks
 
 from a10_octavia.common import a10constants
 from a10_octavia.controller.worker.tasks import a10_compute_tasks as compute_tasks
 from a10_octavia.controller.worker.tasks import a10_database_tasks
 from a10_octavia.controller.worker.tasks import a10_network_tasks
+from a10_octavia.controller.worker.tasks import glm_tasks
 from a10_octavia.controller.worker.tasks import vthunder_tasks
 
 CONF = cfg.CONF
@@ -46,7 +48,6 @@ class VThunderFlows(object):
         create_vthunder_flow.add(database_tasks.CreateAmphoraInDB(
             name=sf_name + '-' + constants.CREATE_AMPHORA_INDB,
             provides=constants.AMPHORA_ID))
-
         create_vthunder_flow.add(compute_tasks.ComputeCreate(
             name=sf_name + '-' + constants.COMPUTE_CREATE,
             requires=(constants.AMPHORA_ID,
@@ -56,7 +57,6 @@ class VThunderFlows(object):
         create_vthunder_flow.add(database_tasks.UpdateAmphoraComputeId(
             name=sf_name + '-' + constants.UPDATE_AMPHORA_COMPUTEID,
             requires=(constants.AMPHORA_ID, constants.COMPUTE_ID)))
-
         create_vthunder_flow.add(database_tasks.MarkAmphoraBootingInDB(
             name=sf_name + '-' + constants.MARK_AMPHORA_BOOTING_INDB,
             requires=(constants.AMPHORA_ID, constants.COMPUTE_ID)))
@@ -75,6 +75,27 @@ class VThunderFlows(object):
             vthunder_tasks.VThunderComputeConnectivityWait(
                 name=sf_name + '-' + constants.AMP_COMPUTE_CONNECTIVITY_WAIT,
                 requires=(a10constants.VTHUNDER, constants.AMPHORA)))
+        create_vthunder_flow.add(vthunder_tasks.EnableInterfaceOnSpare(
+            name=sf_name + '-' + a10constants.ENABLE_VTHUNDER_INTERFACE,
+            requires=(a10constants.VTHUNDER)))
+        create_vthunder_flow.add(
+            vthunder_tasks.UpdateAcosVersionInVthunderEntry(
+                name=sf_name + '-' + a10constants.UPDATE_ACOS_VERSION_IN_VTHUNDER_ENTRY,
+                requires=(a10constants.VTHUNDER)))
+        create_vthunder_flow.add(
+            database_tasks.MarkAmphoraReadyInDB(
+                name=sf_name + '-' + a10constants.MARK_AMPHORA_READY_INDB,
+                requires=(constants.AMPHORA)))
+        create_vthunder_flow.add(self.get_glm_license_subflow(
+            prefix=a10constants.SPARE_VTHUNDER_CREATE, role=a10constants.SPARE_VTHUNDER))
+        create_vthunder_flow.add(
+            vthunder_tasks.CreateHealthMonitorOnVThunder(
+                name=sf_name + '-' + a10constants.CREATE_HEALTH_MONITOR_ON_SPARE,
+                requires=(a10constants.VTHUNDER)))
+
+        create_vthunder_flow.add(a10_database_tasks.MarkVThunderStatusInDB(
+            requires=(a10constants.VTHUNDER),
+            inject={"status": a10constants.READY}))
         return create_vthunder_flow
 
     def get_vthunder_for_lb_subflow(
@@ -95,6 +116,7 @@ class VThunderFlows(object):
         allocate_and_associate_amp = a10_database_tasks.MapLoadbalancerToAmphora(
             name=sf_name + '-' + constants.MAP_LOADBALANCER_TO_AMPHORA,
             requires=constants.LOADBALANCER,
+            inject={a10constants.ROLE: role},
             provides=constants.AMPHORA_ID)
 
         create_amp = self._get_create_amp_for_lb_subflow(prefix, role)
@@ -127,7 +149,7 @@ class VThunderFlows(object):
             provides=constants.AMPHORA_ID))
         # VIP subnet integration at bootup
         create_amp_for_lb_subflow.add(database_tasks.ReloadLoadBalancer(
-            name=sf_name + '-' + constants.RELOADLOAD_BALANCER,
+            name=sf_name + '-' + a10constants.RELOADLOAD_BALANCER,
             requires=constants.LOADBALANCER_ID,
             provides=constants.LOADBALANCER))
         require_server_group_id_condition = (
@@ -168,20 +190,35 @@ class VThunderFlows(object):
             name=sf_name + '-' + constants.UPDATE_AMPHORA_INFO,
             requires=(constants.AMPHORA_ID, constants.COMPUTE_OBJ),
             provides=constants.AMPHORA))
-        # create vThunder entry in custom DB
+        # Create vThunder entry in custom DB
         create_amp_for_lb_subflow.add(a10_database_tasks.CreateVThunderEntry(
             name=sf_name + '-' + a10constants.CREATE_VTHUNDER_ENTRY,
             requires=(constants.AMPHORA, constants.LOADBALANCER),
             inject={a10constants.ROLE: role, a10constants.STATUS: constants.PENDING_CREATE}))
-        # Get VThunder details from database
+        # Rebind requires vthunder in store and vMaster requires vThunder
         create_amp_for_lb_subflow.add(a10_database_tasks.GetVThunderByLoadBalancer(
             name=sf_name + '-' + a10constants.VTHUNDER_BY_LB,
             requires=constants.LOADBALANCER,
             provides=a10constants.VTHUNDER))
+        # Get VThunder details from database
+        if role == constants.ROLE_BACKUP:
+            create_amp_for_lb_subflow.add(
+                a10_database_tasks.GetBackupVThunderByLoadBalancer(
+                    requires=constants.LOADBALANCER,
+                    provides=a10constants.BACKUP_VTHUNDER))
+            create_amp_for_lb_subflow.add(
+                vthunder_tasks.VThunderComputeConnectivityWait(
+                    name=sf_name + '-' + a10constants.BACKUP_CONNECTIVITY_WAIT,
+                    rebind={a10constants.VTHUNDER: a10constants.BACKUP_VTHUNDER},
+                    requires=constants.AMPHORA))
+        else:
+            create_amp_for_lb_subflow.add(
+                vthunder_tasks.VThunderComputeConnectivityWait(
+                    name=sf_name + '-' + a10constants.WAIT_FOR_VTHUNDER_CONNECTIVITY,
+                    requires=(a10constants.VTHUNDER, constants.AMPHORA)))
+        # License the vThunder-Amphora
         create_amp_for_lb_subflow.add(
-            vthunder_tasks.VThunderComputeConnectivityWait(
-                name=sf_name + '-' + a10constants.WAIT_FOR_VTHUNDER_CONNECTIVITY,
-                requires=(a10constants.VTHUNDER, constants.AMPHORA)))
+            *self.get_glm_license_subflow(prefix + '-' + role, role))
         create_amp_for_lb_subflow.add(
             database_tasks.MarkAmphoraAllocatedInDB(
                 name=sf_name + '-' + constants.MARK_AMPHORA_ALLOCATED_INDB,
@@ -190,13 +227,6 @@ class VThunderFlows(object):
             name=sf_name + '-' + constants.RELOAD_AMPHORA,
             requires=constants.AMPHORA_ID,
             provides=constants.AMPHORA))
-        create_amp_for_lb_subflow.add(a10_network_tasks.GetLBResourceSubnet(
-            name=sf_name + '-' + a10constants.GET_LB_RESOURCE,
-            rebind={a10constants.LB_RESOURCE: constants.LOADBALANCER},
-            provides=constants.SUBNET))
-        create_amp_for_lb_subflow.add(vthunder_tasks.AllowL2DSR(
-            name=sf_name + '-' + a10constants.ALLOW_L2DSR,
-            requires=(constants.SUBNET, constants.AMPHORA)))
         if role == constants.ROLE_MASTER:
             create_amp_for_lb_subflow.add(database_tasks.MarkAmphoraMasterInDB(
                 name=sf_name + '-' + constants.MARK_AMP_MASTER_INDB,
@@ -211,6 +241,22 @@ class VThunderFlows(object):
                     name=sf_name + '-' + constants.MARK_AMP_STANDALONE_INDB,
                     requires=constants.AMPHORA))
 
+        if role == constants.ROLE_BACKUP:
+            create_amp_for_lb_subflow.add(
+                a10_database_tasks.GetBackupVThunderByLoadBalancer(
+                    name=sf_name + '-' + a10constants.BACKUP_VTHUNDER,
+                    requires=constants.LOADBALANCER,
+                    provides=a10constants.BACKUP_VTHUNDER))
+            create_amp_for_lb_subflow.add(
+                vthunder_tasks.UpdateAcosVersionInVthunderEntry(
+                    name=sf_name + '-' + a10constants.UPDATE_ACOS_VERSION_FOR_BACKUP_VTHUNDER,
+                    rebind={a10constants.VTHUNDER: a10constants.BACKUP_VTHUNDER}))
+        else:
+            create_amp_for_lb_subflow.add(
+                vthunder_tasks.UpdateAcosVersionInVthunderEntry(
+                    name=sf_name + '-' + a10constants.UPDATE_ACOS_VERSION_FOR_BACKUP_VTHUNDER,
+                    requires=(a10constants.VTHUNDER)))
+
         return create_amp_for_lb_subflow
 
     def _allocate_amp_to_lb_decider(self, history):
@@ -231,11 +277,38 @@ class VThunderFlows(object):
         vthunder_for_amphora_subflow.add(database_tasks.CreateAmphoraInDB(
             name=sf_name + '-' + constants.CREATE_AMPHORA_INDB,
             provides=constants.AMPHORA_ID))
-        vthunder_for_amphora_subflow.add(compute_tasks.ValidateComputeForProject(
+        vthunder_for_amphora_subflow.add(a10_database_tasks.ValidateComputeForProject(
             name=sf_name + '-' + a10constants.VALIDATE_COMPUTE_FOR_PROJECT,
             requires=constants.LOADBALANCER,
             inject={"role": role},
             provides=constants.COMPUTE_ID))
+
+        # if no compute, use spare vThunder and prepare network for spare vThunder
+        vthunder_for_amphora_subflow.add(a10_database_tasks.GetSpareComputeForProject(
+            name=sf_name + '-' + a10constants.GET_SPARE_COMPUTE_FOR_PROJECT,
+            requires=constants.COMPUTE_ID,
+            provides=(constants.COMPUTE_ID, a10constants.SPARE_VTHUNDER)))
+        vthunder_for_amphora_subflow.add(a10_network_tasks.PlugVipNetworkOnSpare(
+            name=sf_name + '-' + a10constants.PLUG_VIP_NETWORK_ON_SPARE,
+            requires=(a10constants.SPARE_VTHUNDER, constants.LOADBALANCER),
+            provides=a10constants.ADDED_NETWORK))
+        vthunder_for_amphora_subflow.add(vthunder_tasks.SparePostNetworkPlug(
+            name=sf_name + '-' + a10constants.POST_SPARE_PLUG_NETWORK,
+            rebind={a10constants.VTHUNDER: a10constants.SPARE_VTHUNDER},
+            requires=(a10constants.ADDED_NETWORK)))
+        vthunder_for_amphora_subflow.add(a10_database_tasks.GetVThunderAmphora(
+            name=sf_name + '-' + a10constants.GET_VTHUNDER_AMPHORA,
+            rebind={a10constants.VTHUNDER: a10constants.SPARE_VTHUNDER},
+            provides=constants.AMPHORA))
+        vthunder_for_amphora_subflow.add(vthunder_tasks.VThunderComputeConnectivityWait(
+            name=sf_name + '-' + constants.AMP_COMPUTE_CONNECTIVITY_WAIT,
+            rebind={a10constants.VTHUNDER: a10constants.SPARE_VTHUNDER},
+            requires=(constants.AMPHORA)))
+        vthunder_for_amphora_subflow.add(vthunder_tasks.EnableInterfaceOnSpare(
+            name=sf_name + '-' + a10constants.ENABLE_VTHUNDER_INTERFACE,
+            rebind={a10constants.VTHUNDER: a10constants.SPARE_VTHUNDER},
+            requires=(a10constants.ADDED_NETWORK)))
+
         vthunder_for_amphora_subflow.add(database_tasks.UpdateAmphoraComputeId(
             name=sf_name + '-' + constants.UPDATE_AMPHORA_COMPUTEID,
             requires=(constants.AMPHORA_ID, constants.COMPUTE_ID)))
@@ -258,7 +331,7 @@ class VThunderFlows(object):
             requires=constants.LOADBALANCER,
             provides=a10constants.VTHUNDER))
         vthunder_for_amphora_subflow.add(database_tasks.ReloadLoadBalancer(
-            name=sf_name + '-' + constants.RELOADLOAD_BALANCER,
+            name=sf_name + '-' + a10constants.RELOADLOAD_BALANCER,
             requires=constants.LOADBALANCER_ID,
             provides=constants.LOADBALANCER))
         vthunder_for_amphora_subflow.add(a10_network_tasks.GetLBResourceSubnet(
@@ -293,24 +366,87 @@ class VThunderFlows(object):
             name=sf_name + '-' + constants.RELOAD_AMPHORA,
             requires=constants.AMPHORA_ID,
             provides=constants.AMPHORA))
-        vthunder_for_amphora_subflow.add(vthunder_tasks.AllowL2DSR(
-            name=sf_name + '-' + a10constants.ALLOW_L2DSR,
-            requires=(constants.SUBNET, constants.AMPHORA)))
         if role == constants.ROLE_MASTER:
             vthunder_for_amphora_subflow.add(database_tasks.MarkAmphoraMasterInDB(
                 name=sf_name + '-' + constants.MARK_AMP_MASTER_INDB,
                 requires=constants.AMPHORA))
+            vthunder_for_amphora_subflow.add(
+                vthunder_tasks.UpdateAcosVersionInVthunderEntry(
+                    name=sf_name + '-' + a10constants.UPDATE_ACOS_VERSION_FOR_BACKUP_VTHUNDER,
+                    requires=(a10constants.VTHUNDER)))
         elif role == constants.ROLE_BACKUP:
             vthunder_for_amphora_subflow.add(database_tasks.MarkAmphoraBackupInDB(
                 name=sf_name + '-' + constants.MARK_AMP_BACKUP_INDB,
                 requires=constants.AMPHORA))
+            vthunder_for_amphora_subflow.add(
+                a10_database_tasks.GetBackupVThunderByLoadBalancer(
+                    name=sf_name + '-' + a10constants.BACKUP_VTHUNDER,
+                    requires=constants.LOADBALANCER,
+                    provides=a10constants.BACKUP_VTHUNDER))
+            vthunder_for_amphora_subflow.add(
+                vthunder_tasks.UpdateAcosVersionInVthunderEntry(
+                    name=sf_name + '-' + a10constants.UPDATE_ACOS_VERSION_FOR_BACKUP_VTHUNDER,
+                    rebind={a10constants.VTHUNDER: a10constants.BACKUP_VTHUNDER}))
         elif role == constants.ROLE_STANDALONE:
             vthunder_for_amphora_subflow.add(
                 database_tasks.MarkAmphoraStandAloneInDB(
                     name=sf_name + '-' + constants.MARK_AMP_STANDALONE_INDB,
                     requires=constants.AMPHORA))
+            vthunder_for_amphora_subflow.add(
+                vthunder_tasks.UpdateAcosVersionInVthunderEntry(
+                    name=sf_name + '-' + a10constants.UPDATE_ACOS_VERSION_FOR_BACKUP_VTHUNDER,
+                    requires=(a10constants.VTHUNDER)))
+
+        # If spare vThunder is used, remove spare vThunder the database
+        vthunder_for_amphora_subflow.add(a10_database_tasks.DeleteStaleSpareVThunder(
+            name=sf_name + '-' + a10constants.DELETE_STALE_SPARE_VTHUNDER,
+            requires=(a10constants.SPARE_VTHUNDER)))
         return vthunder_for_amphora_subflow
 
+    def get_glm_license_subflow(self, prefix, role):
+        sf_name = prefix + '-' + a10constants.ACTIVATE_GLM_LICENSE_SUBFLOW
+        glm_license_subflow = linear_flow.Flow(sf_name)
+
+        if role == constants.ROLE_BACKUP:
+            glm_license_subflow.add(vthunder_tasks.SetVThunderHostname(
+                name=sf_name + '-' + a10constants.SET_VTHUNDER_HOSTNAME,
+                requires=constants.AMPHORA,
+                rebind={a10constants.VTHUNDER: a10constants.BACKUP_VTHUNDER}
+            ))
+            glm_license_subflow.add(glm_tasks.ConfigureForwardProxyServer(
+                name=sf_name + '-' + a10constants.CONFIGURE_PROXY_SERVER,
+                requires=constants.FLAVOR,
+                rebind={a10constants.VTHUNDER: a10constants.BACKUP_VTHUNDER}
+            ))
+            glm_license_subflow.add(glm_tasks.DNSConfiguration(
+                name=sf_name + '-' + a10constants.CONFIGURE_DNS_NAMESERVERS,
+                requires=constants.FLAVOR,
+                rebind={a10constants.VTHUNDER: a10constants.BACKUP_VTHUNDER},
+            ))
+            glm_license_subflow.add(glm_tasks.ActivateFlexpoolLicense(
+                name=sf_name + '-' + a10constants.ACTIVATE_FLEXPOOL_LICENSE,
+                requires=(constants.AMPHORA, constants.FLAVOR),
+                rebind={a10constants.VTHUNDER: a10constants.BACKUP_VTHUNDER},
+            ))
+        else:
+            glm_license_subflow.add(vthunder_tasks.SetVThunderHostname(
+                name=sf_name + '-' + a10constants.SET_VTHUNDER_HOSTNAME,
+                requires=(constants.AMPHORA, a10constants.VTHUNDER)
+            ))
+            glm_license_subflow.add(glm_tasks.ConfigureForwardProxyServer(
+                name=sf_name + '-' + a10constants.CONFIGURE_PROXY_SERVER,
+                requires=(constants.FLAVOR, a10constants.VTHUNDER)
+            ))
+            glm_license_subflow.add(glm_tasks.DNSConfiguration(
+                name=sf_name + '-' + a10constants.CONFIGURE_DNS_NAMESERVERS,
+                requires=(constants.FLAVOR, a10constants.VTHUNDER)
+            ))
+            glm_license_subflow.add(glm_tasks.ActivateFlexpoolLicense(
+                name=sf_name + '-' + a10constants.ACTIVATE_FLEXPOOL_LICENSE,
+                requires=(constants.AMPHORA, a10constants.VTHUNDER, constants.FLAVOR),
+            ))
+        return glm_license_subflow
+
     def get_vrrp_subflow(self, prefix):
         sf_name = prefix + '-' + constants.GET_VRRP_SUBFLOW
         vrrp_subflow = linear_flow.Flow(sf_name)
@@ -344,10 +480,6 @@ class VThunderFlows(object):
             requires=(a10constants.VTHUNDER, a10constants.SET_ID),
             rebind={a10constants.VTHUNDER: a10constants.BACKUP_VTHUNDER}))
         vrrp_subflow.add(self._get_vrrp_status_subflow(sf_name))
-        # Wait for aVCS sync
-        vrrp_subflow.add(vthunder_tasks.VCSSyncWait(
-            name=sf_name + '-' + a10constants.VCS_SYNC_WAIT + '-for-thunder',
-            requires=a10constants.VTHUNDER))
 
         return vrrp_subflow
 
@@ -373,25 +505,6 @@ class VThunderFlows(object):
 
     def _configure_vrrp_subflow(self, sf_name):
         configure_vrrp_subflow = linear_flow.Flow(sf_name)
-        # VRID Configuration
-        configure_vrrp_subflow.add(vthunder_tasks.ConfigureVRID(
-            name=sf_name + '-' + a10constants.CONFIGURE_VRID_FOR_MASTER_VTHUNDER,
-            requires=(a10constants.VTHUNDER)))
-        configure_vrrp_subflow.add(vthunder_tasks.ConfigureVRID(
-            name=sf_name + '-' + a10constants.CONFIGURE_VRID_FOR_BACKUP_VTHUNDER,
-            rebind={a10constants.VTHUNDER: a10constants.BACKUP_VTHUNDER}))
-        # VRRP synch
-        configure_vrrp_subflow.add(vthunder_tasks.ConfigureVRRPSync(
-            name=sf_name + '-' + a10constants.CONFIGURE_VRRP_SYNC,
-            requires=(a10constants.VTHUNDER, a10constants.BACKUP_VTHUNDER)))
-        # Wait for VRRP synch
-        configure_vrrp_subflow.add(vthunder_tasks.VThunderComputeConnectivityWait(
-            name=sf_name + '-' + a10constants.WAIT_FOR_MASTER_SYNC,
-            requires=(a10constants.VTHUNDER, constants.AMPHORA)))
-        configure_vrrp_subflow.add(vthunder_tasks.VThunderComputeConnectivityWait(
-            name=sf_name + '-' + a10constants.WAIT_FOR_BACKUP_SYNC,
-            rebind={a10constants.VTHUNDER: a10constants.BACKUP_VTHUNDER},
-            requires=(constants.AMPHORA)))
         # Configure aVCS
         configure_vrrp_subflow.add(vthunder_tasks.ConfigureaVCSMaster(
             name=sf_name + '-' + a10constants.CONFIGURE_AVCS_SYNC_FOR_MASTER,
@@ -412,23 +525,19 @@ class VThunderFlows(object):
         sf_name = prefix + '-' + constants.GET_AMPHORA_FOR_LB_SUBFLOW
 
         amp_for_lb_flow = linear_flow.Flow(sf_name)
-
         amp_for_lb_flow.add(a10_database_tasks.CreateRackVthunderEntry(
             name=sf_name + '-' + 'create_rack_vThunder_entry_in_database',
             requires=(constants.LOADBALANCER, a10constants.VTHUNDER_CONFIG)))
         amp_for_lb_flow.add(a10_database_tasks.GetVThunderByLoadBalancer(
             requires=constants.LOADBALANCER,
             provides=a10constants.VTHUNDER))
-        amp_for_lb_flow.add(vthunder_tasks.HandleACOSPartitionChange(
-            name=sf_name + '-' + a10constants.CHANGE_PARTITION,
-            requires=a10constants.VTHUNDER))
         return amp_for_lb_flow
 
     def _is_vrrp_configured(self, history):
         """Checks whether vrrp is configured
         :returns: True if vrrp is configured
         """
-        return history[history.keys()[0]]
+        return history[list(history.keys())[0]]
 
     def get_write_memory_flow(self, vthunder, store, deleteCompute):
         """Perform write memory for thunder """
@@ -515,3 +624,189 @@ class VThunderFlows(object):
 
         store.update(vthunder_store)
         return reload_check_flow
+
+    def get_failover_spare_vthunder_flow(self):
+        """Perform failover for spare vthunder"""
+        sf_name = 'a10-house-keeper-failover-spare-vthunder'
+        failover_flow = linear_flow.Flow(sf_name)
+
+        failover_flow.add(a10_database_tasks.GetVThunderAmphora(
+            name=sf_name + '-' + a10constants.GET_VTHUNDER_AMPHORA,
+            requires=a10constants.VTHUNDER,
+            provides=constants.AMPHORA))
+        failover_flow.add(compute.ComputeDelete(
+            name=sf_name + '-' + a10constants.COMPUTE_DELETE,
+            requires=constants.AMPHORA))
+        failover_flow.add(a10_database_tasks.DeleteStaleSpareVThunder(
+            name=sf_name + '-' + a10constants.DELETE_STALE_SPARE_VTHUNDER,
+            rebind={a10constants.SPARE_VTHUNDER: a10constants.VTHUNDER}))
+
+        return failover_flow
+
+    def _get_failover_use_spare_amphora_subflow(self, prefix):
+        """Flow to get spare amphora for failvoer"""
+        sf_name = 'failover_get_spare_amphora'
+        get_spare_flow = linear_flow.Flow(sf_name)
+        get_spare_flow.add(a10_network_tasks.PlugNetworksByID(
+            name=sf_name + '-' + a10constants.PLUG_NETWORK_BY_IDS,
+            requires=(a10constants.NETWORK_LIST),
+            rebind={a10constants.VTHUNDER: a10constants.SPARE_VTHUNDER},
+            provides=a10constants.ADDED_NETWORK))
+        get_spare_flow.add(vthunder_tasks.SparePostNetworkPlug(
+            name=sf_name + '-' + a10constants.POST_SPARE_PLUG_NETWORK,
+            rebind={a10constants.VTHUNDER: a10constants.SPARE_VTHUNDER},
+            requires=(a10constants.ADDED_NETWORK)))
+        get_spare_flow.add(a10_database_tasks.GetVThunderAmphora(
+            name=sf_name + '-' + a10constants.GET_VTHUNDER_AMPHORA,
+            rebind={a10constants.VTHUNDER: a10constants.SPARE_VTHUNDER},
+            provides=constants.AMPHORA))
+        get_spare_flow.add(vthunder_tasks.VThunderComputeConnectivityWait(
+            name=sf_name + '-' + constants.AMP_COMPUTE_CONNECTIVITY_WAIT,
+            rebind={a10constants.VTHUNDER: a10constants.SPARE_VTHUNDER},
+            requires=(constants.AMPHORA)))
+        get_spare_flow.add(vthunder_tasks.EnableInterfaceOnSpare(
+            name=sf_name + '-' + a10constants.ENABLE_VTHUNDER_INTERFACE,
+            rebind={a10constants.VTHUNDER: a10constants.SPARE_VTHUNDER},
+            requires=(a10constants.ADDED_NETWORK)))
+
+        return get_spare_flow
+
+    def _get_failover_create_amphora_subflow(self, prefix):
+        """Flow to create amphora for failover"""
+        create_amp_flow = linear_flow.Flow(constants.CREATE_AMPHORA_FLOW)
+        sf_name = prefix + '-' + a10constants.SPARE_VTHUNDER_CREATE
+
+        create_amp_flow.add(database_tasks.CreateAmphoraInDB(
+            name=sf_name + '-' + constants.CREATE_AMPHORA_INDB,
+            provides=constants.AMPHORA_ID))
+        create_amp_flow.add(compute_tasks.ComputeCreate(
+            name=sf_name + '-' + constants.COMPUTE_CREATE,
+            requires=(constants.AMPHORA_ID, a10constants.NETWORK_LIST),
+            provides=constants.COMPUTE_ID))
+        create_amp_flow.add(database_tasks.UpdateAmphoraComputeId(
+            name=sf_name + '-' + constants.UPDATE_AMPHORA_COMPUTEID,
+            requires=(constants.AMPHORA_ID, constants.COMPUTE_ID)))
+
+        create_amp_flow.add(database_tasks.MarkAmphoraBootingInDB(
+            name=sf_name + '-' + constants.MARK_AMPHORA_BOOTING_INDB,
+            requires=(constants.AMPHORA_ID, constants.COMPUTE_ID)))
+        create_amp_flow.add(compute_tasks.ComputeActiveWait(
+            name=sf_name + '-' + constants.COMPUTE_WAIT,
+            requires=(constants.COMPUTE_ID, constants.AMPHORA_ID),
+            provides=constants.COMPUTE_OBJ))
+        create_amp_flow.add(database_tasks.UpdateAmphoraInfo(
+            name=sf_name + '-' + constants.UPDATE_AMPHORA_INFO,
+            requires=(constants.AMPHORA_ID, constants.COMPUTE_OBJ),
+            provides=constants.AMPHORA))
+        create_amp_flow.add(a10_database_tasks.CreateSpareVThunderEntry(
+            requires=(constants.AMPHORA),
+            provides=a10constants.SPARE_VTHUNDER))
+        create_amp_flow.add(
+            vthunder_tasks.VThunderComputeConnectivityWait(
+                name=sf_name + '-' + constants.AMP_COMPUTE_CONNECTIVITY_WAIT,
+                requires=constants.AMPHORA,
+                rebind={a10constants.VTHUNDER: a10constants.SPARE_VTHUNDER}))
+        create_amp_flow.add(a10_database_tasks.MarkVThunderStatusInDB(
+            rebind={a10constants.VTHUNDER: a10constants.SPARE_VTHUNDER},
+            inject={"status": a10constants.READY}))
+        create_amp_flow.add(
+            vthunder_tasks.UpdateAcosVersionInVthunderEntry(
+                name=sf_name + '-' + a10constants.UPDATE_ACOS_VERSION_IN_VTHUNDER_ENTRY,
+                rebind={a10constants.VTHUNDER: a10constants.SPARE_VTHUNDER}))
+        create_amp_flow.add(vthunder_tasks.EnableInterfaceOnSpare(
+            name=sf_name + '-' + a10constants.ENABLE_VTHUNDER_INTERFACE,
+            rebind={a10constants.VTHUNDER: a10constants.SPARE_VTHUNDER}))
+        return create_amp_flow
+
+    def _get_failover_amphora_subflow(self, prefix):
+        """Flow to get vThunder for failover process"""
+        sf_name = prefix + '-' + a10constants.GET_AMPHORA_FOR_FAILOVER
+        failover_get_amp_flow = graph_flow.Flow(sf_name)
+
+        check_spare = a10_database_tasks.TryGetSpareCompute(
+            name=sf_name + '-' + 'check-spare-exist',
+            provides=(a10constants.SPARE_VTHUNDER))
+        get_spare_amp = self._get_failover_use_spare_amphora_subflow(sf_name)
+        create_amp = self._get_failover_create_amphora_subflow(sf_name)
+        failover_get_amp_flow.add(check_spare, get_spare_amp, create_amp)
+        failover_get_amp_flow.link(check_spare, get_spare_amp,
+                                   decider=self._allocate_amp_to_lb_decider,
+                                   decider_depth='flow')
+        failover_get_amp_flow.link(check_spare, create_amp,
+                                   decider=self._create_new_amp_for_lb_decider,
+                                   decider_depth='flow')
+        return failover_get_amp_flow
+
+    def _get_failover_configure_vcs_subflow(self, prefix):
+        """Flow to get failover vcs configure process"""
+        sf_name = prefix + '-' + 'conf-vcs'
+        failover_vcs_flow = linear_flow.Flow(sf_name)
+
+        failover_vcs_flow.add(a10_database_tasks.GetProjectVRRPSetId(
+            name=sf_name + '-' + a10constants.GET_VRRP_SET_ID_INDB,
+            requires=a10constants.VTHUNDER,
+            provides=a10constants.SET_ID))
+        failover_vcs_flow.add(a10_database_tasks.GetVThunderDeviceID(
+            name=sf_name + '-' + a10constants.GET_VCS_DEVICE_ID,
+            requires=a10constants.VTHUNDER,
+            provides=a10constants.DEVICE_ID))
+        failover_vcs_flow.add(vthunder_tasks.ConfigureVRRPFailover(
+            rebind={a10constants.VTHUNDER: a10constants.SPARE_VTHUNDER},
+            requires=(a10constants.DEVICE_ID, a10constants.SET_ID)))
+        failover_vcs_flow.add(vthunder_tasks.ConfigureaVCSFailover(
+            name=sf_name + '-' + a10constants.CONFIGURE_AVCS_FOR_FAILOVER,
+            rebind={a10constants.VTHUNDER: a10constants.SPARE_VTHUNDER},
+            requires=a10constants.DEVICE_ID))
+        # Wait for aVCS sync
+        failover_vcs_flow.add(vthunder_tasks.VCSSyncWait(
+            name=sf_name + '-' + a10constants.VCS_SYNC_WAIT,
+            rebind={a10constants.VTHUNDER: a10constants.SPARE_VTHUNDER}))
+
+        return failover_vcs_flow
+
+    def get_failover_vcs_vthunder_flow(self):
+        """Perform failover for VCS vthunder device"""
+        sf_name = 'a10-house-keeper-failover-vcs-vthunder'
+        failover_flow = linear_flow.Flow(sf_name)
+
+        failover_flow.add(a10_database_tasks.GetComputeVThundersAndLoadBalancers(
+            name=sf_name + '-' + a10constants.GET_LBS_BY_THUNDER,
+            requires=a10constants.VTHUNDER,
+            provides=(a10constants.VTHUNDER_LIST, a10constants.LOADBALANCERS_LIST)))
+        # Switch role may not necessary
+        failover_flow.add(a10_database_tasks.SetVThunderToStandby(
+            name=sf_name + '-' + a10constants.SET_VTHUNDER_TO_STANDBY,
+            requires=a10constants.VTHUNDER_LIST))
+        failover_flow.add(a10_database_tasks.LoadBalancerListToErrorOnRevertTask(
+            name=sf_name + '-' + a10constants.MARK_LB_LIST_ERROR_ON_REVERT,
+            requires=a10constants.LOADBALANCERS_LIST))
+        failover_flow.add(a10_database_tasks.MarkLoadBalancersPendingUpdateInDB(
+            name=sf_name + '-' + a10constants.MARK_LB_PENIND_UPDATE_IN_DB,
+            requires=a10constants.LOADBALANCERS_LIST))
+        failover_flow.add(a10_network_tasks.GetVThunderNetworkList(
+            name=sf_name + '-' + a10constants.GET_VTHUNDER_NETWORK_LIST,
+            requires=a10constants.VTHUNDER,
+            provides=a10constants.NETWORK_LIST))
+        failover_flow.add(self._get_failover_amphora_subflow(sf_name))
+        failover_flow.add(self._get_failover_configure_vcs_subflow(sf_name))
+
+        failover_flow.add(compute_tasks.DeleteStaleCompute(
+            name=sf_name + '-' + 'delete-stale-compute',
+            requires=(a10constants.VTHUNDER)))
+        failover_flow.add(a10_database_tasks.FailoverPostDbUpdate(
+            name=sf_name + '-' + a10constants.POST_FAILOVER_DB_UPDATE,
+            requires=(a10constants.VTHUNDER, a10constants.SPARE_VTHUNDER)))
+        failover_flow.add(a10_database_tasks.DeleteStaleSpareVThunder(
+            name=sf_name + '-' + a10constants.DELETE_STALE_SPARE_VTHUNDER,
+            requires=(a10constants.SPARE_VTHUNDER)))
+        failover_flow.add(a10_database_tasks.MarkLoadBalancersActiveInDB(
+            name=sf_name + '-' + a10constants.MARK_LB_ACTIVE_IN_DB,
+            requires=a10constants.LOADBALANCERS_LIST))
+        return failover_flow
+
+    def get_failover_restore_vthunder_flow(self):
+        """Perform vthunder restore"""
+        sf_name = 'a10-house-keeper-failover-restore-vthunder'
+        failover_flow = linear_flow.Flow(sf_name)
+
+        return failover_flow
