@@ -20,7 +20,9 @@ from taskflow.types import failure
 
 from octavia.common import constants
 from octavia.common import exceptions
-from octavia.controller.worker.tasks.compute_tasks import BaseComputeTask
+from octavia.controller.worker.v1.tasks.compute_tasks import BaseComputeTask
+
+from a10_octavia.common import exceptions as a10_exception
 
 CONF = cfg.CONF
 LOG = logging.getLogger(__name__)
@@ -31,17 +33,31 @@ class ComputeCreate(BaseComputeTask):
 
     def execute(self, amphora_id, loadbalancer=None,
                 build_type_priority=constants.LB_CREATE_NORMAL_PRIORITY,
-                server_group_id=None, ports=None):
+                server_group_id=None, ports=None, network_list=None):
 
         ports = ports or []
-        network_ids = CONF.a10_controller_worker.amp_boot_network_list[:]
-        # Injecting VIP network ID
+        boot_net_list = CONF.a10_controller_worker.amp_boot_network_list
+        mgmt_net = CONF.a10_controller_worker.amp_mgmt_network
+        mgmt_net = boot_net_list[0] if boot_net_list and not mgmt_net else mgmt_net
+        if not mgmt_net:
+            raise a10_exception.NetworkNotFoundToBootAmphora()
+
+        network_ids = set(boot_net_list) if boot_net_list else set()
+        if CONF.glm_license.amp_license_network:
+            network_ids.add(CONF.glm_license.amp_license_network)
+        if network_list:
+            network_ids = network_ids.union(set(network_list))
         if loadbalancer:
-            if loadbalancer.vip.network_id not in network_ids:
-                network_ids.append(loadbalancer.vip.network_id)
+            network_ids.add(loadbalancer.vip.network_id)
+
+        if mgmt_net in network_ids:
+            network_ids.remove(mgmt_net)
+
+        network_ids = list(network_ids)
+        network_ids.insert(0, mgmt_net)
+
         LOG.debug("Compute create execute for amphora with id %s", amphora_id)
         key_name = CONF.a10_controller_worker.amp_ssh_key_name
-
         try:
             if CONF.a10_controller_worker.build_rate_limit != -1:
                 self.rate_limit.add_to_build_request_queue(
@@ -50,7 +66,6 @@ class ComputeCreate(BaseComputeTask):
             compute_id = self.compute.build(
                 name="amphora-" + amphora_id,
                 amphora_flavor=CONF.a10_controller_worker.amp_flavor_id,
-                image_id=CONF.a10_controller_worker.amp_image_id,
                 image_tag=CONF.a10_controller_worker.amp_image_tag,
                 image_owner=CONF.a10_controller_worker.amp_image_owner_id,
                 key_name=key_name,
@@ -61,6 +76,7 @@ class ComputeCreate(BaseComputeTask):
 
             LOG.debug("Server created with id: %s for amphora id: %s",
                       compute_id, amphora_id)
+
             return compute_id
 
         except Exception as e:
@@ -126,3 +142,33 @@ class NovaServerGroupCreate(BaseComputeTask):
                       "still be in use for server group: %(sg)s due to "
                       "error: %(except)s",
                       {'sg': server_group_id, 'except': e})
+
+
+class CheckAmphoraStatus(BaseComputeTask):
+    """Check for the compute driver for the amphora status."""
+
+    def execute(self, vthunder):
+        """Check for the compute driver for the amphora status."""
+        if vthunder:
+            try:
+                amp, fault = self.compute.get_amphora(vthunder.compute_id)
+                if amp.status != constants.ACTIVE:
+                    return False
+                return True
+            except Exception as e:
+                LOG.exception("Failed to find compute %s du to: %s",
+                              vthunder.compute_id, str(e))
+                return False
+
+
+class DeleteStaleCompute(BaseComputeTask):
+    """Delete Stale Compute for Failover"""
+
+    def execute(self, vthunder):
+        if vthunder:
+            try:
+                self.compute.delete(vthunder.compute_id)
+            except Exception as e:
+                LOG.exception("Failed to delete stale compute %s due to: %s",
+                              vthunder.compute_id, str(e))
+                # pass here in case the compute is already deleted
