@@ -25,6 +25,7 @@ from taskflow.types import failure
 
 from octavia.common import constants
 from octavia.controller.worker import task_utils
+from octavia.db import api as db_apis
 from octavia.network import base
 from octavia.network import data_models as n_data_models
 
@@ -34,6 +35,7 @@ from a10_octavia.common import exceptions
 from a10_octavia.common import utils as a10_utils
 from a10_octavia.controller.worker.tasks.decorators import axapi_client_decorator
 from a10_octavia.controller.worker.tasks import utils as a10_task_utils
+from a10_octavia.db import repositories as a10_repo
 
 LOG = logging.getLogger(__name__)
 CONF = cfg.CONF
@@ -46,6 +48,7 @@ class BaseNetworkTask(task.Task):
         super(BaseNetworkTask, self).__init__(**kwargs)
         self._network_driver = None
         self.task_utils = task_utils.TaskUtils()
+        self.vthunder_repo = a10_repo.VThunderRepository()
 
     @property
     def network_driver(self):
@@ -58,7 +61,7 @@ class CalculateAmphoraDelta(BaseNetworkTask):
 
     default_provides = constants.DELTA
 
-    def execute(self, loadbalancers_list, amphora):
+    def execute(self, loadbalancers_list, amphora, member_list):
         LOG.debug("Calculating network delta for amphora id: %s", amphora.id)
         # Figure out what networks we want
         # seed with lb network(s)
@@ -68,7 +71,7 @@ class CalculateAmphoraDelta(BaseNetworkTask):
         for loadbalancer in loadbalancers_list:
             for pool in loadbalancer.pools:
                 for member in pool.members:
-                    if member.subnet_id:
+                    if member.subnet_id and member in member_list:
                         member_networks = [
                             self.network_driver.get_subnet(member.subnet_id).network_id]
                     else:
@@ -76,7 +79,7 @@ class CalculateAmphoraDelta(BaseNetworkTask):
                                     "issuance of create command/API call for member %s. "
                                     "Skipping interface attachment", member.id)
 
-                desired_network_ids.update(member_networks)
+                    desired_network_ids.update(member_networks)
 
         loadbalancer_networks = [
             self.network_driver.get_subnet(loadbalancer.vip.subnet_id).network_id
@@ -114,7 +117,7 @@ class CalculateDelta(BaseNetworkTask):
 
     default_provides = constants.DELTAS
 
-    def execute(self, loadbalancer, loadbalancers_list):
+    def execute(self, loadbalancer, loadbalancers_list, member_list):
         """Compute which NICs need to be plugged
 
         for the amphora to become operational.
@@ -131,7 +134,7 @@ class CalculateDelta(BaseNetworkTask):
             lambda amp: amp.status == constants.AMPHORA_ALLOCATED,
                 loadbalancer.amphorae):
 
-            delta = calculate_amp.execute(loadbalancers_list, amphora)
+            delta = calculate_amp.execute(loadbalancers_list, amphora, member_list)
             deltas[amphora.id] = delta
         return deltas
 
@@ -213,6 +216,35 @@ class UnPlugNetworks(BaseNetworkTask):
                 LOG.exception("Unable to unplug network")
 
 
+class PlugNetworksByID(BaseNetworkTask):
+    """Task to plug the networks in the list."""
+
+    def __init__(self, *arg, **kwargs):
+        self.added_network = []
+        super(PlugNetworksByID, self).__init__(*arg, **kwargs)
+
+    def execute(self, vthunder, network_list):
+        nets = set(network_list)
+        nics = self.network_driver.get_plugged_networks(vthunder.compute_id)
+        exist_ids = set([nic.network_id for nic in nics])
+
+        self.added_network = list(nets.difference(exist_ids))
+        for net in self.added_network:
+            try:
+                self.network_driver.plug_network(vthunder.compute_id, net)
+            except Exception as e:
+                LOG.exception("Failed to plug network: %s", net)
+                raise e
+        return self.added_network
+
+    def revert(self, vthunder, network_list, *args, **kwargs):
+        for net in self.added_network:
+            try:
+                self.network_driver.unplug_network(vthunder.compute_id, net)
+            except base.NetworkNotFound:
+                pass
+
+
 class GetMemberPorts(BaseNetworkTask):
 
     def execute(self, loadbalancer, amphora):
@@ -820,6 +852,7 @@ class HandleVRIDFloatingIP(BaseNetworkTask):
                 if new_ip != vrid.vrid_floating_ip:
                     vrid = self._replace_vrid_port(vrid, vrid_subnet, lb_resource, new_ip)
                     update_vrid_flag = True
+
             if isinstance(subnet, list):
                 subnet_ids = set([s.id for s in subnet])
                 if vrid_subnet.id in subnet_ids or vrid.vrid_floating_ip in existing_fips:
@@ -1116,6 +1149,59 @@ class GetPoolsOnThunder(BaseNetworkTask):
             return
 
 
+class GetVThunderNetworkList(BaseNetworkTask):
+
+    def execute(self, vthunder):
+        try:
+            nics = self.network_driver.get_plugged_networks(vthunder.compute_id)
+
+            # in case the compute is deleted by some reason
+            if not nics:
+                # Since stale vthunder will switch to backup, so peer is current master
+                peer = self.vthunder_repo.get_vthunder_from_lb(
+                    db_apis.get_session(), vthunder.loadbalancer_id)
+
+                # in case role switch failed
+                if peer.compute_id == vthunder.compute_id:
+                    peer = self.vthunder_repo.get_backup_vthunder_from_lb(
+                        db_apis.get_session(), vthunder.loadbalancer_id)
+                nics = self.network_driver.get_plugged_networks(peer.compute_id)
+
+            network_ids = [nic.network_id for nic in nics]
+            return network_ids
+        except Exception as e:
+            LOG.exception("Failed to get network list for vthunder duo to %s", str(e))
+            raise e
+
+
+class PlugVipNetworkOnSpare(BaseNetworkTask):
+    """Task to plug vip network on spare vThunder"""
+
+    def __init__(self, *arg, **kwargs):
+        self.added_network = []
+        super(PlugVipNetworkOnSpare, self).__init__(*arg, **kwargs)
+
+    def execute(self, spare_vthunder, loadbalancer):
+        if spare_vthunder:
+            try:
+                nics = self.network_driver.get_plugged_networks(spare_vthunder.compute_id)
+                network_ids = [nic.network_id for nic in nics]
+                vip_net_id = self.network_driver.get_subnet(loadbalancer.vip.subnet_id).network_id
+                if vip_net_id not in network_ids:
+                    self.network_driver.plug_network(spare_vthunder.compute_id, vip_net_id)
+                    self.added_network.append(vip_net_id)
+            except Exception as e:
+                LOG.exception("Failed to check vip subnet on spare vThunder du to %s", str(e))
+            return self.added_network
+
+    def revert(self, spare_vthunder, loadbalancer, *args, **kwargs):
+        for net in self.added_network:
+            try:
+                self.network_driver.unplug_network(spare_vthunder.compute_id, net)
+            except base.NetworkNotFound:
+                pass
+
+
 class ValidateSubnet(BaseNetworkTask):
 
     def execute(self, member):
