@@ -84,29 +84,17 @@ class MemberCreate(task.Task):
         else:
             status = True
 
-        health_check = None
-        if pool.health_monitor:
-            health_check = pool.health_monitor.id
-
         try:
             try:
                 server_name = _get_server_name(self.axapi_client, member)
                 self.axapi_client.slb.server.update(server_name, member.ip_address, status=status,
-                                                    health_check=health_check,
                                                     server_templates=server_temp,
                                                     **server_args)
                 LOG.debug("Successfully created member: %s", member.id)
             except acos_errors.NotFound:
-                if CONF.a10_global.nlbaas_member_names:
-                    server_name = '_{}_{}_neutron'.format(
-                        member.project_id[:5],
-                        member.ip_address.replace('.', '_'))
-                else:
-                    server_name = '{}_{}'.format(
-                        member.project_id[:5],
-                        member.ip_address.replace('.', '_'))                
+                server_name = '{}_{}'.format(member.project_id[:5],
+                                             member.ip_address.replace('.', '_'))
                 self.axapi_client.slb.server.create(server_name, member.ip_address, status=status,
-                                                    health_check=health_check,
                                                     server_templates=server_temp,
                                                     **server_args)
                 LOG.debug("Successfully created member: %s", member.id)
@@ -178,7 +166,8 @@ class MemberUpdate(task.Task):
     """Task to update member"""
 
     @axapi_client_decorator
-    def execute(self, member, vthunder, pool, flavor=None):
+    def execute(self, member, vthunder, pool, flavor=None, update_dict={}):
+        member.__dict__.update(update_dict)
         server_args = utils.meta(member, 'server', {})
         server_args = utils.dash_to_underscore(server_args)
         server_args['conn_limit'] = CONF.server.conn_limit
@@ -204,15 +193,10 @@ class MemberUpdate(task.Task):
         else:
             status = True
 
-        health_check = None
-        if pool.health_monitor:
-            health_check = pool.health_monitor.id
-
         try:
             server_name = _get_server_name(self.axapi_client, member)
             port_list = self.axapi_client.slb.server.get(server_name)['server'].get('port-list')
             self.axapi_client.slb.server.replace(server_name, member.ip_address, status=status,
-                                                 health_check=health_check,
                                                  server_templates=server_temp,
                                                  port_list=port_list,
                                                  **server_args)
