@@ -37,7 +37,8 @@ from a10_octavia.controller.worker.tasks import a10_database_tasks as task
 from a10_octavia.tests.common import a10constants
 from a10_octavia.tests.unit import base
 
-VTHUNDER = data_models.VThunder()
+VTHUNDER = data_models.VThunder(amphora_id=a10constants.MOCK_AMPHORA_ID,
+                                compute_id=a10constants.MOCK_COMPUTE_ID)
 HW_THUNDER = data_models.HardwareThunder(
     project_id=a10constants.MOCK_PROJECT_ID,
     device_name="rack_thunder_1",
@@ -55,6 +56,7 @@ VRID = data_models.VRID(id=1, vrid=0,
                         owner=a10constants.MOCK_PROJECT_ID,
                         vrid_port_id=uuidutils.generate_uuid(),
                         vrid_floating_ip='10.0.12.32')
+VRRP_SET = data_models.VrrpSet(set_id=a10constants.MOCK_SET_ID)
 LISTENER = o_data_models.Listener(id=a10constants.MOCK_LISTENER_ID, load_balancer=LB)
 POOL = o_data_models.Pool(id=a10constants.MOCK_POOL_ID, load_balancer=LB)
 HM = o_data_models.HealthMonitor(id=a10constants, pool=POOL)
@@ -74,6 +76,11 @@ SUBNET = n_data_models.Subnet(id=uuidutils.generate_uuid())
 NAT_POOL = data_models.NATPool(id=uuidutils.generate_uuid(),
                                port_id=a10constants.MOCK_PORT_ID)
 
+AMPHORA = o_data_models.Amphora(id=a10constants.MOCK_AMPHORA_ID,
+                                role=a10constants.MOCK_TOPOLOGY_ROLE_MASTER)
+AMPHORA_BLADE = o_data_models.Amphora(id=a10constants.MOCK_AMPHORA_ID,
+                                      role=a10constants.MOCK_TOPOLOGY_ROLE_BACKUP)
+
 
 class TestA10DatabaseTasks(base.BaseTaskTestCase):
 
@@ -88,6 +95,8 @@ class TestA10DatabaseTasks(base.BaseTaskTestCase):
         self.conf.register_opts(
             config_options.A10_HARDWARE_THUNDER_OPTS,
             group=a10constants.HARDWARE_THUNDER_CONF_SECTION)
+        self.conf.register_opts(config_options.A10_GLOBAL_OPTS,
+                                group=a10constants.A10_GLOBAL_OPTS)
         self.db_session = mock.patch(
             'a10_octavia.controller.worker.tasks.a10_database_tasks.db_apis.get_session')
         self.db_session.start()
@@ -115,8 +124,22 @@ class TestA10DatabaseTasks(base.BaseTaskTestCase):
         vthunder = mock_get_vthunder.execute(LB)
         self.assertEqual(vthunder, None)
 
+    def test_get_backup_vthunder_by_loadbalancer(self):
+        vthunder = copy.deepcopy(VTHUNDER)
+        vthunder.role = "BACKUP"
+        self.conf.config(
+            group=a10constants.A10_GLOBAL_CONF_SECTION,
+            use_parent_partition=True)
+        mock_get_vthunder = task.GetVThunderByLoadBalancer()
+        mock_get_vthunder.vthunder_repo = mock.MagicMock()
+        mock_get_vthunder.vthunder_repo.get_vthunder_from_lb.return_value = None
+        mock_get_vthunder.vthunder_repo.get_backup_vthunder_from_lb.return_value = vthunder
+        backup_vthunder = mock_get_vthunder.execute(LB, False)
+        self.assertEqual(backup_vthunder, vthunder)
+
     def test_get_vrid_for_project_member_hmt_use_partition(self):
         thunder = copy.deepcopy(HW_THUNDER)
+        lb = copy.deepcopy(LB)
         thunder.hierarchical_multitenancy = 'enable'
         thunder.vrid_floating_ip = VRID.vrid_floating_ip
         hardware_device_conf = self._generate_hardware_device_conf(thunder)
@@ -134,11 +157,12 @@ class TestA10DatabaseTasks(base.BaseTaskTestCase):
         mock_vrid_entry.vrid_repo = mock.Mock()
         mock_vrid_entry.vthunder_repo = mock.Mock()
         mock_vrid_entry.vrid_repo.get_vrid_from_owner.return_value = VRID
-        vrid = mock_vrid_entry.execute([a10constants.MOCK_PROJECT_ID], thunder)
+        vrid = mock_vrid_entry.execute([a10constants.MOCK_PROJECT_ID], thunder, lb)
         self.assertEqual(VRID, vrid)
 
     def test_get_vrid_for_project(self):
         thunder = copy.deepcopy(HW_THUNDER)
+        lb = copy.deepcopy(LB)
         thunder.hierarchical_multitenancy = 'disable'
         thunder.vrid_floating_ip = VRID.vrid_floating_ip
         hardware_device_conf = self._generate_hardware_device_conf(thunder)
@@ -156,7 +180,7 @@ class TestA10DatabaseTasks(base.BaseTaskTestCase):
         mock_vrid_entry.vrid_repo = mock.Mock()
         mock_vrid_entry.vthunder_repo = mock.Mock()
         mock_vrid_entry.vrid_repo.get_vrid_from_owner.return_value = VRID
-        vrid = mock_vrid_entry.execute(MEMBER_1, thunder)
+        vrid = mock_vrid_entry.execute(MEMBER_1, thunder, lb)
         mock_vrid_entry.vthunder_repo.get_partition_for_project.assert_not_called()
         self.assertEqual(VRID, vrid)
 
@@ -542,3 +566,119 @@ class TestA10DatabaseTasks(base.BaseTaskTestCase):
         lb_task.vthunder_repo = mock.MagicMock()[1:999]
         lb_task.vthunder_repo.get_vthunder_by_project_id.return_value = vthunder
         self.assertRaises(o_exceptions.InvalidTopology, lb_task.execute, LB, "SINGLE")
+
+    @mock.patch('octavia.statistics.stats_base.update_stats_via_driver')
+    def test_update_listeners_stats_with_statistics(self, mock_stats_base):
+        LISTENER_STATS = o_data_models.ListenerStatistics(listener_id=uuidutils.generate_uuid())
+        mock_get_listener = task.UpdateListenersStats()
+        mock_get_listener.listener_repo = mock.MagicMock()
+        mock_get_listener.listener_repo.get_all.return_value = [LISTENER], None
+        mock_get_listener.listener_stats_repo = mock.MagicMock()
+        mock_get_listener.listener_stats_repo.get_all.return_value = [LISTENER_STATS], None
+        mock_get_listener.execute([LISTENER_STATS])
+        mock_stats_base.assert_called_once_with([LISTENER_STATS])
+
+    def test_GetVThunderAmphora(self):
+        db_task = task.GetVThunderAmphora()
+        vthunder = copy.deepcopy(VTHUNDER)
+        db_task.amphora_repo = mock.MagicMock()
+        db_task.amphora_repo.get.return_value = AMPHORA
+        amp = db_task.execute(vthunder)
+        self.assertEqual(amp.id, a10constants.MOCK_AMPHORA_ID)
+
+    def test_GetProjectVRRPSetId(self):
+        db_task = task.GetProjectVRRPSetId()
+        self.conf.config(
+            group=a10constants.A10_CONTROLLER_WORKER_CONF_SECTION,
+            amp_boot_network_list=[1, 2])
+        vthunder = copy.deepcopy(VTHUNDER)
+        db_task.vrrp_set_repo = mock.MagicMock()
+        db_task.vrrp_set_repo.get.return_value = VRRP_SET
+        setid = db_task.execute(vthunder)
+        self.assertEqual(setid, a10constants.MOCK_SET_ID)
+
+    def test_GetSpareComputeForProject(self):
+        db_task = task.GetSpareComputeForProject()
+        vthunder = copy.deepcopy(VTHUNDER)
+        db_task.vthunder_repo = mock.MagicMock()
+        db_task.vthunder_repo.get_spare_vthunder.return_value = vthunder
+        db_task.vthunder_repo.set_spare_vthunder_status = mock.Mock()
+        cid, vth = db_task.execute()
+        self.assertEqual(cid, a10constants.MOCK_COMPUTE_ID)
+
+    def test_TryGetSpareCompute(self):
+        db_task = task.TryGetSpareCompute()
+        vthunder = copy.deepcopy(VTHUNDER)
+        db_task.vthunder_repo = mock.MagicMock()
+        db_task.vthunder_repo.get_spare_vthunder.return_value = vthunder
+        vth = db_task.execute()
+        self.assertEqual(vth, vthunder)
+
+    def test_GetComputeVThundersAndLoadBalancers(self):
+        db_task = task.GetComputeVThundersAndLoadBalancers()
+        vthunder = copy.deepcopy(VTHUNDER)
+        db_task.vthunder_repo = mock.MagicMock()
+        db_task.vthunder_repo.get_compute_vthunders.return_value = [vthunder]
+        db_task.loadbalancer_repo = mock.MagicMock()
+        db_task.loadbalancer_repo.get = mock.MagicMock()
+        db_task.loadbalancer_repo.get.return_value = LB
+        vlist, llist = db_task.execute(vthunder)
+        self.assertEqual(vlist[0], vthunder)
+        self.assertEqual(llist[0], LB)
+
+    def test_DeleteStaleSpareVThunder(self):
+        db_task = task.DeleteStaleSpareVThunder()
+        vthunder = copy.deepcopy(VTHUNDER)
+        db_task.amphora_repo = mock.Mock()
+        db_task.amphora_repo.delete = mock.Mock()
+        db_task.vthunder_repo = mock.Mock()
+        db_task.vthunder_repo.delete = mock.Mock()
+        db_task.execute(vthunder)
+        db_task.amphora_repo.delete.assert_called_once_with(mock.ANY,
+                                                            id=a10constants.MOCK_AMPHORA_ID)
+        db_task.vthunder_repo.delete.assert_called_once_with(mock.ANY, id=vthunder.id)
+
+    def test_GetVThunderDeviceID(self):
+        db_task = task.GetVThunderDeviceID()
+        vthunder = copy.deepcopy(VTHUNDER)
+        db_task.amphora_repo = mock.MagicMock()
+        db_task.amphora_repo.get.return_value = AMPHORA
+        setid = db_task.execute(vthunder)
+        self.assertEqual(setid, 1)
+        db_task.amphora_repo.get.return_value = AMPHORA_BLADE
+        setid = db_task.execute(vthunder)
+        self.assertEqual(setid, 2)
+
+    def test_FailoverPostDbUpdate(self):
+        db_task = task.FailoverPostDbUpdate()
+        vthunder = copy.deepcopy(VTHUNDER)
+        db_task.amphora_repo = mock.Mock()
+        db_task.amphora_repo.get.return_value = AMPHORA
+        db_task.amphora_repo.update = mock.Mock()
+        db_task.vthunder_repo = mock.Mock()
+        db_task.vthunder_repo.get_all_vthunder_by_address.return_value = [vthunder]
+        db_task.vthunder_repo.update = mock.Mock()
+        db_task.execute(vthunder, vthunder)
+        db_task.vthunder_repo.update.assert_called_once_with(mock.ANY,
+                                                             id=vthunder.id,
+                                                             ip_address=mock.ANY,
+                                                             compute_id=mock.ANY)
+        db_task.amphora_repo.update.assert_called_once_with(mock.ANY,
+                                                            id=a10constants.MOCK_AMPHORA_ID,
+                                                            compute_id=mock.ANY,
+                                                            lb_network_ip=mock.ANY,
+                                                            image_id=mock.ANY,
+                                                            compute_flavor=mock.ANY)
+
+    def test_count_lb_thunder_partition_success(self):
+        vthunder = copy.deepcopy(VTHUNDER)
+        mock_count_lb = task.CountLBThunderPartition()
+        mock_count_lb.vthunder_repo.get_lb_count_vthunder_partition = mock.Mock()
+        mock_count_lb.vthunder_repo.get_lb_count_vthunder_partition.return_value = 1
+        lb_count = mock_count_lb.execute(vthunder)
+        self.assertEqual(1, lb_count)
+
+    def test_count_lb_thunder_partition_no_thunder(self):
+        mock_count_lb = task.CountLBThunderPartition()
+        lb_count = mock_count_lb.execute(None)
+        self.assertEqual(0, lb_count)
