@@ -180,7 +180,8 @@ DEV_CONF_DICT = {'[dev]rack_thunder_1': FLAVOR_DEV1,
 DEV_FLAVOR = {'device_name': 'rack_thunder_1'}
 
 VIP = o_data_models.Vip(ip_address="1.1.1.1")
-AMPHORAE = [o_data_models.Amphora(id=a10constants.MOCK_AMPHORA_ID)]
+AMPHORA = o_data_models.Amphora(id=a10constants.MOCK_AMPHORA_ID)
+AMPHORAE = [AMPHORA]
 LB = o_data_models.LoadBalancer(
     id=a10constants.MOCK_LOAD_BALANCER_ID, vip=VIP,
     amphorae=AMPHORAE, project_id=PROJECT_ID)
@@ -921,29 +922,8 @@ class TestVThunderTasks(base.BaseTaskTestCase):
         self.client_mock.system.action.write_memory.assert_not_called()
         self.client_mock.system.action.reload_reboot_for_interface_detachment.assert_not_called()
 
-    def test_GetVThunderInterface_execute_for_vMaster(self):
-        thunder = copy.deepcopy(VTHUNDER)
-        mock_task = task.GetVThunderInterface()
-        mock_task.axapi_client = self.client_mock
-        self.client_mock.system.action.get_vcs_summary_oper.return_value = VCS_MASTER_VBLADE
-        self.client_mock.interface.get_list.return_value = INTERFACES
-        thunder.ip_address = "10.0.0.1"
-        mock_task.execute(thunder)
-        self.client_mock.system.action.setInterface.assert_not_called()
-        self.assertEqual(mock_task.execute(thunder), ([1], []))
-
-    def test_GetVThunderInterface_execute_for_vBlade(self):
-        thunder = copy.deepcopy(VTHUNDER)
-        mock_task = task.GetVThunderInterface()
-        mock_task.axapi_client = self.client_mock
-        self.client_mock.system.action.get_vcs_summary_oper.return_value = VCS_MASTER_VBLADE
-        self.client_mock.interface.get_list.return_value = INTERFACES
-        thunder.ip_address = "10.0.0.2"
-        mock_task.execute(thunder)
-        self.client_mock.system.action.setInterface.assert_not_called()
-        self.assertEqual(mock_task.execute(thunder), ([], [1]))
-
-    def test_EnableInterface_execute_for_single_topology(self):
+    @mock.patch('stevedore.driver.DriverManager')
+    def test_EnableInterface_execute_for_single_topology(self, mock_drivermgr):
         thunder = copy.deepcopy(VTHUNDER)
         added_ports = {'amphora_id': ''}
         thunder.topology = "SINGLE"
@@ -952,10 +932,14 @@ class TestVThunderTasks(base.BaseTaskTestCase):
         mock_task.loadbalancer_repo.check_lb_exists_in_project.return_value = True
         mock_task.axapi_client = self.client_mock
         self.client_mock.interface.get_list.return_value = INTERFACES
+        mock_driver = mock.MagicMock()
+        mock_drivermgr.return_value = mock_driver
+        mock_drivermgr.get_plugged_networks.return_value = [NETWORK_11]
         mock_task.execute(thunder, LB, added_ports)
         self.client_mock.system.action.setInterface.assert_not_called()
 
-    def test_EnableInterface_execute_for_active_standby_topology(self):
+    @mock.patch('stevedore.driver.DriverManager')
+    def test_EnableInterface_execute_for_active_standby_topology(self, mock_drivermgr):
         thunder = copy.deepcopy(VTHUNDER)
         added_ports = {'amphora_id': ''}
         thunder.topology = "ACTIVE_STANDBY"
@@ -964,6 +948,9 @@ class TestVThunderTasks(base.BaseTaskTestCase):
         mock_task.loadbalancer_repo.check_lb_exists_in_project.return_value = True
         mock_task.axapi_client = self.client_mock
         self.client_mock.interface.get_list.return_value = INTERFACES
+        mock_driver = mock.MagicMock()
+        mock_drivermgr.return_value = mock_driver
+        mock_drivermgr.get_plugged_networks.return_value = [NETWORK_11]
         mock_task.execute(thunder, LB, added_ports)
         self.client_mock.system.action.setInterface.assert_not_called()
 
@@ -1020,3 +1007,112 @@ class TestVThunderTasks(base.BaseTaskTestCase):
         mock_task.execute(SUBNET, AMPHORAE, lb_count, lb_count, flavor_data=DEPLOYMENT_FLAVOR)
         self.client_mock.remove_any_source_ip_on_egress.assert_called_with(
             SUBNET.network_id, AMPHORAE[0])
+
+    def test_get_listeners_stats(self):
+        vthunder = copy.deepcopy(VTHUNDER)
+        vthunder.loadbalancer_id = a10constants.MOCK_LOAD_BALANCER_ID
+        lb = copy.deepcopy(LB)
+        lb.provisioning_status = "ACTIVE"
+        STATS = {
+            "port-list": [
+                {
+                    "stats": {
+                        "curr_conn": 0, "total_conn": 1,
+                        "total_fwd_bytes": 684, "total_rev_bytes": 705
+                    },
+                    "port-number": 80,
+                    "protocol": "http"
+                }
+            ]
+        }
+        mock_task = task.GetListenersStats()
+        mock_task.loadbalancer_repo = mock.MagicMock()
+        mock_task.loadbalancer_repo.get.return_value = lb
+        mock_task.axapi_client = self.client_mock
+        mock_task.axapi_client.slb.virtual_server.stats.return_value = STATS
+        mock_task.execute(vthunder)
+        self.client_mock.slb.virtual_server.stats.assert_called_with(
+            name=a10constants.MOCK_LOAD_BALANCER_ID, timeout=mock.ANY, max_retries=mock.ANY)
+
+    @mock.patch('a10_octavia.controller.worker.tasks.vthunder_tasks.time')
+    def test_SparePostNetowrkPlug(self, mock_time):
+        mock_task = task.SparePostNetworkPlug()
+        mock_task.axapi_client = self.client_mock
+        thunder = copy.deepcopy(VTHUNDER)
+        net_list = [1, 2]
+        mock_task.execute(thunder, net_list)
+        self.client_mock.system.action.write_memory.assert_called_with()
+        self.client_mock.system.action.reload_reboot_for_interface_attachment.assert_called_with(
+            thunder.acos_version)
+
+    def test_EnableInterfaceOnSpare(self):
+        mock_task = task.EnableInterfaceOnSpare()
+        mock_task.axapi_client = self.client_mock
+        thunder = copy.deepcopy(VTHUNDER)
+        net_list = [1, 2]
+        iface = {'interface': {'ethernet-list': [
+            {'action': "disable", 'ifnum': 2}
+        ]}}
+        mock_task.axapi_client.interface.get_list.return_value = iface
+        mock_task.execute(thunder, net_list)
+        self.client_mock.system.action.setInterface.assert_called_with(2)
+
+    def test_ConfigureVRRPFailover(self):
+        mock_task = task.ConfigureVRRPFailover()
+        mock_task.axapi_client = self.client_mock
+        thunder = copy.deepcopy(VTHUNDER)
+        mock_task.execute(thunder, 'device1', 'set1')
+        self.client_mock.system.action.configureVRRP.assert_called_with('device1', 'set1')
+
+    def test_ConfigureaVCSFailover(self):
+        mock_task = task.ConfigureaVCSFailover()
+        mock_task.axapi_client = self.client_mock
+        thunder = copy.deepcopy(VTHUNDER)
+        mock_task.execute(thunder, 'device1')
+        self.client_mock.system.action.set_vcs_device.assert_called_with('device1', 100)
+        self.client_mock.system.action.vcs_enable.assert_called_with()
+        self.client_mock.system.action.write_memory.assert_called_with()
+        self.client_mock.system.action.vcs_reload.assert_called_with()
+
+    def test_SetHostName_execute_set_hostname(self):
+        vthunder = copy.deepcopy(VTHUNDER)
+        amphora = copy.deepcopy(AMPHORA)
+        amphora.id = '295990755083049101712519384016336453749'
+        interfaces = {
+            'interface': {
+                'ethernet-list': []
+            }
+        }
+
+        expected_host = 'amphora-29599075508304910171251'
+
+        flexpool_task = task.SetVThunderHostname()
+        flexpool_task.axapi_client = self.client_mock
+        flexpool_task.axapi_client.interface.get_list.return_value = interfaces
+
+        flexpool_task.execute(vthunder, amphora)
+        self.client_mock.system.action.set_hostname.assert_called_with(expected_host)
+
+    def test_DeleteHealthMonitorOnVThunder_success(self):
+        mock_task = task.DeleteHealthMonitorOnVThunder()
+        mock_task.axapi_client = self.client_mock
+        thunder = copy.deepcopy(VTHUNDER)
+        mock_lb_count_thunder_partition = 0
+        mock_task.execute(mock_lb_count_thunder_partition, thunder)
+        self.client_mock.slb.server.delete.assert_called_with(
+            a10constants.MOCK_OCTAVIA_HEALTH_MANAGER_CONTROLLER)
+        self.client_mock.slb.hm.delete.assert_called_with(
+            a10constants.MOCK_OCTAVIA_HEALTH_MONITOR)
+
+    def test_DeleteHealthMonitorOnVThunder_no_vthunder(self):
+        mock_task = task.DeleteHealthMonitorOnVThunder()
+        mock_lb_count_thunder_partition = 0
+        delete_hm = mock_task.execute(mock_lb_count_thunder_partition, None)
+        self.assertEqual(None, delete_hm)
+
+    def test_DeleteHealthMonitorOnVThunder_active_lb(self):
+        mock_task = task.DeleteHealthMonitorOnVThunder()
+        mock_lb_count_thunder_partition = 2
+        thunder = copy.deepcopy(VTHUNDER)
+        delete_hm = mock_task.execute(mock_lb_count_thunder_partition, thunder)
+        self.assertEqual(None, delete_hm)
